@@ -4,9 +4,6 @@ Base class for interpolation methods that calculate values for each dimension in
 Based on Tables in NPSS, and was added to bridge the gap between some of the slower scipy
 implementations.
 """
-from __future__ import division, print_function, absolute_import
-from six.moves import range
-
 import numpy as np
 
 from openmdao.components.interp_util.interp_akima import InterpAkima
