@@ -1,8 +1,6 @@
 """
 Unit tests for the BalanceComp.
 """
-from __future__ import print_function, division, absolute_import
-
 import os
 import unittest
 import warnings
@@ -11,7 +9,7 @@ import numpy as np
 from numpy.testing import assert_almost_equal
 
 import openmdao.api as om
-from openmdao.utils.assert_utils import assert_warning, assert_no_warning
+from openmdao.utils.assert_utils import assert_warning, assert_no_warning, assert_check_partials
 
 
 class TestBalanceComp(unittest.TestCase):
@@ -45,8 +43,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=2e-5, rtol=2e-5)
 
         # set an actual solver, and re-setup. Then check derivatives at a converged point
         prob.model.linear_solver = om.DirectSolver()
@@ -60,8 +57,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_create_on_init(self):
 
@@ -95,8 +91,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_balance_comp_options_exclude_no_error(self):
 
@@ -114,7 +109,6 @@ class TestBalanceComp(unittest.TestCase):
         prob.model.recording_options['record_inputs'] = True
         prob.model.recording_options['record_outputs'] = True
         prob.model.recording_options['record_residuals'] = True
-        bal.recording_options['record_metadata'] = False
 
         prob.setup()
 
@@ -135,7 +129,6 @@ class TestBalanceComp(unittest.TestCase):
 
         prob.model.add_recorder(recorder)
 
-        bal.recording_options['record_metadata'] = True
         bal.recording_options['options_excludes'] = ['guess_func']
 
         prob.setup()
@@ -176,8 +169,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_vectorized(self):
 
@@ -217,8 +209,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=2e-5, rtol=2e-5)
 
     def test_vectorized_no_normalization(self):
 
@@ -258,8 +249,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_vectorized_with_mult(self):
 
@@ -303,8 +293,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_vectorized_with_default_mult(self):
         """
@@ -346,8 +335,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_shape(self):
         n = 100
@@ -419,8 +407,7 @@ class TestBalanceComp(unittest.TestCase):
             warnings.filterwarnings(action="error", category=np.ComplexWarning)
             cpd = prob.check_partials(out_stream=None, method='cs')
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=10)
+        assert_check_partials(cpd, atol=1e-10, rtol=1e-10)
 
     def test_scalar(self):
 
@@ -460,8 +447,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_scalar_with_guess_func(self):
 
@@ -501,8 +487,7 @@ class TestBalanceComp(unittest.TestCase):
         self.assertEqual(model.nonlinear_solver._iter_count, 1)
 
         cpd = prob.check_partials(out_stream=None)
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_scalar_with_guess_func_additional_input(self):
 
@@ -653,8 +638,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_scalar_with_mult(self):
 
@@ -698,8 +682,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_renamed_vars(self):
 
@@ -743,8 +726,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_feature_scalar(self):
         from numpy.testing import assert_almost_equal
@@ -894,8 +876,7 @@ class TestBalanceComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['balance']:
-            assert_almost_equal(cpd['balance'][of, wrt]['abs error'], 0.0, decimal=5)
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
 
 if __name__ == '__main__':  # pragma: no cover
