@@ -5,7 +5,7 @@ import unittest
 import numpy as np
 
 import openmdao.api as om
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 
 
 class TestLinearSystemComp(unittest.TestCase):
@@ -37,14 +37,14 @@ class TestLinearSystemComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['lin.x'], x, .0001)
-        assert_rel_error(self, prob.model._residuals.get_norm(), 0.0, 1e-10)
+        assert_near_equal(prob['lin.x'], x, .0001)
+        assert_near_equal(prob.model._residuals.get_norm(), 0.0, 1e-10)
 
         model.run_apply_nonlinear()
 
         with model._scaled_context_all():
             val = model.lingrp.lin._residuals['x']
-            assert_rel_error(self, val, np.zeros((3, )), tolerance=1e-8)
+            assert_near_equal(val, np.zeros((3, )), tolerance=1e-8)
 
     def test_vectorized(self):
         """Check against the scipy solver."""
@@ -72,14 +72,14 @@ class TestLinearSystemComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['lin.x'], x, .0001)
-        assert_rel_error(self, prob.model._residuals.get_norm(), 0.0, 1e-10)
+        assert_near_equal(prob['lin.x'], x, .0001)
+        assert_near_equal(prob.model._residuals.get_norm(), 0.0, 1e-10)
 
         model.run_apply_nonlinear()
 
         with model._scaled_context_all():
             val = model.lingrp.lin._residuals['x']
-            assert_rel_error(self, val, np.zeros((2, 3)), tolerance=1e-8)
+            assert_near_equal(val, np.zeros((2, 3)), tolerance=1e-8)
 
     def test_vectorized_A(self):
         """Check against the scipy solver."""
@@ -108,14 +108,14 @@ class TestLinearSystemComp(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['lin.x'], x, .0001)
-        assert_rel_error(self, prob.model._residuals.get_norm(), 0.0, 1e-10)
+        assert_near_equal(prob['lin.x'], x, .0001)
+        assert_near_equal(prob.model._residuals.get_norm(), 0.0, 1e-10)
 
         model.run_apply_nonlinear()
 
         with model._scaled_context_all():
             val = model.lingrp.lin._residuals['x']
-            assert_rel_error(self, val, np.zeros((2, 3)), tolerance=1e-8)
+            assert_near_equal(val, np.zeros((2, 3)), tolerance=1e-8)
 
     def test_solve_linear(self):
         """Check against solve_linear."""
@@ -158,25 +158,23 @@ class TestLinearSystemComp(unittest.TestCase):
         d_residuals['lin.x'] = b
         lingrp.run_solve_linear(['linear'], 'fwd')
         sol = d_outputs['lin.x']
-        assert_rel_error(self, sol, x, .0001)
+        assert_near_equal(sol, x, .0001)
 
         # Reverse mode with RHS of self.b_T
         d_outputs['lin.x'] = b_T
         lingrp.run_solve_linear(['linear'], 'rev')
         sol = d_residuals['lin.x']
-        assert_rel_error(self, sol, x, .0001)
+        assert_near_equal(sol, x, .0001)
 
         J = prob.compute_totals(['lin.x'], ['p1.A', 'p2.b', 'lin.x'], return_format='flat_dict')
-        assert_rel_error(self, J['lin.x', 'p1.A'], dx_dA, .0001)
-        assert_rel_error(self, J['lin.x', 'p2.b'], dx_db, .0001)
+        assert_near_equal(J['lin.x', 'p1.A'], dx_dA, .0001)
+        assert_near_equal(J['lin.x', 'p2.b'], dx_db, .0001)
 
         data = prob.check_partials(out_stream=None)
 
         abs_errors = data['lingrp.lin'][('x', 'x')]['abs error']
         self.assertTrue(len(abs_errors) > 0)
-        for match in abs_errors:
-            abs_error = float(match)
-            self.assertTrue(abs_error < 1.e-6)
+        self.assertTrue(abs_errors[0] < 1.e-6)
 
     def test_solve_linear_vectorized(self):
         """Check against solve_linear."""
@@ -221,24 +219,23 @@ class TestLinearSystemComp(unittest.TestCase):
         d_residuals['lin.x'] = b
         lingrp.run_solve_linear(['linear'], 'fwd')
         sol = d_outputs['lin.x']
-        assert_rel_error(self, sol, x, .0001)
+        assert_near_equal(sol, x, .0001)
 
         # Reverse mode with RHS of self.b_T
         d_outputs['lin.x'] = b_T
         lingrp.run_solve_linear(['linear'], 'rev')
         sol = d_residuals['lin.x']
-        assert_rel_error(self, sol, x, .0001)
+        assert_near_equal(sol, x, .0001)
 
         J = prob.compute_totals(['lin.x'], ['p1.A', 'p2.b'], return_format='flat_dict')
-        assert_rel_error(self, J['lin.x', 'p1.A'], dx_dA, .0001)
-        assert_rel_error(self, J['lin.x', 'p2.b'], dx_db, .0001)
+        assert_near_equal(J['lin.x', 'p1.A'], dx_dA, .0001)
+        assert_near_equal(J['lin.x', 'p2.b'], dx_db, .0001)
 
         data = prob.check_partials(out_stream=None)
 
         abs_errors = data['lingrp.lin'][('x', 'x')]['abs error']
         self.assertTrue(len(abs_errors) > 0)
-        for match in abs_errors:
-            abs_error = float(match)
+        self.assertTrue(abs_errors[0] < 1.e-6)
 
     def test_solve_linear_vectorized_A(self):
         """Check against solve_linear."""
@@ -292,24 +289,23 @@ class TestLinearSystemComp(unittest.TestCase):
         d_residuals['lin.x'] = b
         lingrp.run_solve_linear(['linear'], 'fwd')
         sol = d_outputs['lin.x']
-        assert_rel_error(self, sol, x, .0001)
+        assert_near_equal(sol, x, .0001)
 
         # Reverse mode with RHS of self.b_T
         d_outputs['lin.x'] = b_T
         lingrp.run_solve_linear(['linear'], 'rev')
         sol = d_residuals['lin.x']
-        assert_rel_error(self, sol, x, .0001)
+        assert_near_equal(sol, x, .0001)
 
         J = prob.compute_totals(['lin.x'], ['p1.A', 'p2.b'], return_format='flat_dict')
-        assert_rel_error(self, J['lin.x', 'p1.A'], dx_dA, .0001)
-        assert_rel_error(self, J['lin.x', 'p2.b'], dx_db, .0001)
+        assert_near_equal(J['lin.x', 'p1.A'], dx_dA, .0001)
+        assert_near_equal(J['lin.x', 'p2.b'], dx_db, .0001)
 
         data = prob.check_partials(out_stream=None)
 
         abs_errors = data['lingrp.lin'][('x', 'x')]['abs error']
         self.assertTrue(len(abs_errors) > 0)
-        for match in abs_errors:
-            abs_error = float(match)
+        self.assertTrue(abs_errors[0] < 1.e-6)
 
     def test_feature_basic(self):
         import numpy as np
@@ -337,7 +333,7 @@ class TestLinearSystemComp(unittest.TestCase):
 
         prob.run_model()
 
-        assert_rel_error(self, prob['lin.x'], np.array([0.36423841, -0.00662252, -0.4205298 ]), .0001)
+        assert_near_equal(prob['lin.x'], np.array([0.36423841, -0.00662252, -0.4205298 ]), .0001)
 
     def test_feature_vectorized(self):
         import numpy as np
@@ -365,7 +361,7 @@ class TestLinearSystemComp(unittest.TestCase):
 
         prob.run_model()
 
-        assert_rel_error(self, prob['lin.x'], np.array([[ 0.10596026, -0.16556291,  0.48675497],
+        assert_near_equal(prob['lin.x'], np.array([[ 0.10596026, -0.16556291,  0.48675497],
                                                         [ 0.19205298, -0.11258278, -0.14900662]]),
                          .0001)
 
@@ -396,7 +392,7 @@ class TestLinearSystemComp(unittest.TestCase):
 
         prob.run_model()
 
-        assert_rel_error(self, prob['lin.x'], np.array([[-0.78807947,  0.66887417,  0.47350993],
+        assert_near_equal(prob['lin.x'], np.array([[-0.78807947,  0.66887417,  0.47350993],
                                                         [ 0.7       , -1.8       ,  0.75      ]]),
                          .0001)
 
