@@ -7,9 +7,9 @@ import numpy as np
 
 import openmdao.api as om
 from openmdao.components.spline_comp import SPLINE_METHODS
-from openmdao.utils.assert_utils import assert_check_partials, assert_rel_error
+from openmdao.utils.assert_utils import assert_check_partials, assert_near_equal
 from openmdao.utils.general_utils import printoptions
-from openmdao.utils.spline_distributions import sine_distribution
+from openmdao.utils.spline_distributions import cell_centered
 from openmdao.components.interp_util.interp import InterpND
 
 
@@ -58,6 +58,31 @@ class SplineCompTestCase(unittest.TestCase):
         self.prob.setup(force_alloc_complex=True)
         self.prob.run_model()
 
+    def test_small_akima_spline_bug(self):
+        # Fixes a bug that only occure for a 4 point spline.
+        prob = om.Problem()
+
+        num_cp = 4
+        num_radial = 11
+        comp = om.IndepVarComp()
+        comp.add_output("chord_cp", units="m", val=np.array([0.1, 0.2, 0.3, 0.15]))
+        comp.add_output("theta_cp", units="rad", val=np.array([1.0, 0.8, 0.6, 0.4]))
+        prob.model.add_subsystem("inputs_comp", comp, promotes=["*"])
+
+        x_cp = np.linspace(0.0, 1.0, num_cp)
+        x_interp = cell_centered(num_radial, start=0.0, end=1.0)
+        akima_options = {'delta_x': 0.1}
+        comp = om.SplineComp(method='akima', interp_options=akima_options, x_cp_val=x_cp, x_interp_val=x_interp)
+        comp.add_spline(y_cp_name='chord_cp', y_interp_name='chord_interp', y_units='m')
+        comp.add_spline(y_cp_name='theta_cp', y_interp_name='theta_interp', y_units='rad')
+        prob.model.add_subsystem('akima_comp', comp,
+                                 promotes_inputs=['chord_cp', 'theta_cp'],
+                                 promotes_outputs=['chord_interp', 'theta_interp'])
+        prob.setup()
+
+        # Make sure we don't get an exception
+        prob.run_model()
+
     def test_akima_backward_compatibility(self):
 
         comp = om.SplineComp(method='akima', x_cp_val=self.x_cp, x_interp_val=self.x,
@@ -81,7 +106,7 @@ class SplineCompTestCase(unittest.TestCase):
                             20.96983509, 21.37579297, 21.94811407, 22.66809748, 23.51629844,
                             24.47327219, 25.51957398, 26.63575905, 27.80238264, 29.        ]])
 
-        assert_rel_error(self, akima_y.flatten(), self.prob['akima1.y_val'].flatten(), tolerance=1e-8)
+        assert_near_equal(akima_y.flatten(), self.prob['akima1.y_val'].flatten(), tolerance=1e-8)
 
         derivs = self.prob.check_partials(out_stream=None, method='cs')
         assert_check_partials(derivs, atol=1e-14, rtol=1e-14)
@@ -120,7 +145,7 @@ class SplineCompTestCase(unittest.TestCase):
                         6.        ,  6.73660714,  8.46428571, 10.45982143, 12.        ,
                         13.08035714, 14.        ]])
 
-        assert_rel_error(self, y.flatten(), self.prob['akima1.y_val'].flatten(), tolerance=1e-8)
+        assert_near_equal(y.flatten(), self.prob['akima1.y_val'].flatten(), tolerance=1e-8)
 
         derivs = self.prob.check_partials(out_stream=None, method='cs')
         assert_check_partials(derivs, atol=1e-14, rtol=1e-14)
@@ -232,18 +257,18 @@ class SplineCompTestCase(unittest.TestCase):
         xx = prob['interp.h']
 
         with printoptions(precision=3, floatmode='fixed'):
-            assert_rel_error(self, x[0, :], np.array([
+            assert_near_equal(x[0, :], np.array([
                 0., 0.38268343, 0.70710678, 0.92387953, 1.
             ]), 1e-5)
-            assert_rel_error(self, x[1, :], 2.0*np.array([
+            assert_near_equal(x[1, :], 2.0*np.array([
                 0., 0.38268343, 0.70710678, 0.92387953, 1.
             ]), 1e-5)
 
-            assert_rel_error(self, xx[0, :], np.array([
+            assert_near_equal(xx[0, :], np.array([
                 0., 0.06687281, 0.23486869, 0.43286622, 0.6062628,
                 0.74821484, 0.86228902, 0.94134389, 0.98587725, 1.
             ]), 1e-5)
-            assert_rel_error(self, xx[1, :], 2.0*np.array([
+            assert_near_equal(xx[1, :], 2.0*np.array([
                 0., 0.06687281, 0.23486869, 0.43286622, 0.6062628,
                 0.74821484, 0.86228902, 0.94134389, 0.98587725, 1.
             ]), 1e-5)
@@ -251,6 +276,22 @@ class SplineCompTestCase(unittest.TestCase):
 
         derivs = prob.check_partials(out_stream=None, method='cs')
         assert_check_partials(derivs, atol=1e-14, rtol=1e-14)
+        
+    def test_bspline_bug(self):
+        # Tests a bug fix where the interp_options weren't passed into
+        # the bspline interp comp
+        bspline_options = {'order': 3}
+        comp = om.SplineComp(method='bsplines', num_cp=6, x_interp_val=self.x,
+                             interp_options=bspline_options)
+
+        self.prob.model.add_subsystem('atmosphere', comp)
+
+        comp.add_spline(y_cp_name='alt_cp', y_interp_name='alt', y_cp_val=self.y_cp, y_units='kft')
+
+        self.prob.setup(force_alloc_complex=True)
+        
+        # If we set the bspline order to 3, then k should internally be 4
+        self.assertEqual(comp.interps['alt'].table.k, 4)
 
     def test_error_messages(self):
         n_cp = 80
@@ -365,7 +406,7 @@ class SplineCompFeatureTestCase(unittest.TestCase):
                             20.96983509, 21.37579297, 21.94811407, 22.66809748, 23.51629844,
                             24.47327219, 25.51957398, 26.63575905, 27.80238264, 29.        ]])
 
-        assert_rel_error(self, akima_y.flatten(), prob['akima1.y_val'].flatten(), tolerance=1e-8)
+        assert_near_equal(akima_y.flatten(), prob['akima1.y_val'].flatten(), tolerance=1e-8)
 
     def test_multi_splines(self):
 
@@ -417,7 +458,7 @@ class SplineCompFeatureTestCase(unittest.TestCase):
                              17.96032258, 20.14140712, 22.31181718, 24.40891577, 26.27368825, 27.74068235,
                              28.67782484, 29.        ]])
 
-        assert_rel_error(self, akima_y.flatten(), prob['akima1.y_val'].flatten(), tolerance=1e-8)
+        assert_near_equal(akima_y.flatten(), prob['akima1.y_val'].flatten(), tolerance=1e-8)
 
     def test_akima_options(self):
         import numpy as np
@@ -500,7 +541,7 @@ class SplineCompFeatureTestCase(unittest.TestCase):
                         14.99875415, 16.        , 17.93874585, 21.        , 24.625    ,
                         29.        ]])
 
-        assert_rel_error(self, prob['comp1.chord'], y, 1e-6)
+        assert_near_equal(prob['comp1.chord'], y, 1e-6)
 
     def test_bsplines_2to3doc(self):
         from openmdao.utils.spline_distributions import sine_distribution
@@ -536,22 +577,22 @@ class SplineCompFeatureTestCase(unittest.TestCase):
         xx = prob['interp.h']
 
         with printoptions(precision=3, floatmode='fixed'):
-            assert_rel_error(self, x[0, :], np.array([
+            assert_near_equal(x[0, :], np.array([
                 0., 0.38268343, 0.70710678, 0.92387953, 1.
             ]), 1e-5)
-            assert_rel_error(self, x[1, :], 2.0*np.array([
+            assert_near_equal(x[1, :], 2.0*np.array([
                 0., 0.38268343, 0.70710678, 0.92387953, 1.
             ]), 1e-5)
 
-            assert_rel_error(self, xx[0, :], np.array([
+            assert_near_equal(xx[0, :], np.array([
                 0., 0.06687281, 0.23486869, 0.43286622, 0.6062628,
                 0.74821484, 0.86228902, 0.94134389, 0.98587725, 1.
             ]), 1e-5)
-            assert_rel_error(self, xx[1, :], 2.0*np.array([
+            assert_near_equal(xx[1, :], 2.0*np.array([
                 0., 0.06687281, 0.23486869, 0.43286622, 0.6062628,
                 0.74821484, 0.86228902, 0.94134389, 0.98587725, 1.
             ]), 1e-5)
 
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
