@@ -1,17 +1,13 @@
 """Define the IndepVarComp class."""
 
-from __future__ import division
-
 # note: this is a Python 3.3 change, clean this up for OpenMDAO 3.x
 try:
     from collections.abc import Iterable
 except ImportError:
     from collections import Iterable
 
-from six import string_types
-
 from openmdao.core.explicitcomponent import ExplicitComponent
-from openmdao.utils.general_utils import warn_deprecation, make_set
+from openmdao.utils.general_utils import make_set
 
 
 class IndepVarComp(ExplicitComponent):
@@ -37,11 +33,9 @@ class IndepVarComp(ExplicitComponent):
 
         Parameters
         ----------
-        name : str or None or [(str, value), ...] or [(str, value, kwargs), ...]
+        name : str or None
             name of the variable.
             If None, variables should be defined external to this class by calling add_output.
-            For backwards compatibility with OpenMDAO v1, this can also be a list of tuples
-            in the case of declaring multiple variables at once.
         val : float or ndarray
             value of the variable if a single variable is being defined.
         **kwargs : dict
@@ -58,30 +52,12 @@ class IndepVarComp(ExplicitComponent):
             kwargs['tags'] = make_set(kwargs['tags'], name='tags') | {'indep_var'}
 
         # A single variable is declared during instantiation
-        if isinstance(name, string_types):
+        if isinstance(name, str):
             self._indep.append((name, val, kwargs))
-        # Mutiple variables are declared during instantiation (deprecated)
-        elif isinstance(name, Iterable):
-            warn_deprecation('Declaring multiple variables in this way is deprecated. '
-                             'In OpenMDAO 2.x or later, multiple variables should be declared '
-                             'as separate add_output calls.')
 
-            # Loop through each variable (i.e., each tuple)
-            for tup in name:
-                # If valid tuple, assign to (name, val, kwargs); otherwise, raise an exception
-                if isinstance(tup, tuple) and len(tup) == 3:
-                    name_, val, kwargs = tup
-                elif isinstance(tup, tuple) and len(tup) == 2:
-                    name_, val = tup
-                    kwargs = {}
-                else:
-                    raise ValueError(
-                        "IndepVarComp init: arg %s must be a tuple of the "
-                        "form (name, value) or (name, value, keyword_dict)." %
-                        str(tup))
-                self._indep.append((name_, val, kwargs))
         elif name is None:
             pass
+
         else:
             raise ValueError(
                 "first argument to IndepVarComp init must be either of type "
