@@ -27,12 +27,13 @@ from openmdao.error_checking.check_config import _default_checks, _all_checks
 from openmdao.recorders.recording_iteration_stack import _RecIteration
 from openmdao.recorders.recording_manager import RecordingManager, record_viewer_data
 from openmdao.utils.record_util import create_local_meta
-from openmdao.utils.general_utils import ContainsAll, pad_name, simple_warning
+from openmdao.utils.general_utils import ContainsAll, pad_name, simple_warning, warn_deprecation
+
 from openmdao.utils.mpi import FakeComm
 from openmdao.utils.mpi import MPI
 from openmdao.utils.name_maps import prom_name2abs_name
 from openmdao.utils.options_dictionary import OptionsDictionary
-from openmdao.utils.units import get_conversion
+from openmdao.utils.units import unit_conversion
 from openmdao.utils import coloring as coloring_mod
 from openmdao.utils.name_maps import abs_key2rel_key
 from openmdao.vectors.vector import INT_DTYPE
@@ -92,8 +93,6 @@ class Problem(object):
         Derivatives calculation mode assigned by the user.  If set to 'auto', _mode will be
         automatically assigned to 'fwd' or 'rev' based on relative sizes of design variables vs.
         responses.
-    _solver_print_cache : list
-        Allows solver iprints to be set to requested values after setup calls.
     _initial_condition_cache : dict
         Any initial conditions that are set at the problem level via setitem are cached here
         until they can be processed.
@@ -173,8 +172,6 @@ class Problem(object):
 
         self.comm = comm
 
-        self._solver_print_cache = []
-
         self._mode = None  # mode is assigned in setup()
 
         self._initial_condition_cache = {}
@@ -208,6 +205,18 @@ class Problem(object):
         self.recording_options.declare('record_responses', types=bool, default=False,
                                        desc='Set True to record constraints and objectives at the '
                                             'problem level.')
+        self.recording_options.declare('record_inputs', types=bool, default=False,
+                                       desc='Set True to record inputs at the '
+                                            'problem level.')
+        self.recording_options.declare('record_outputs', types=bool, default=True,
+                                       desc='Set True to record outputs at the '
+                                            'problem level.')
+        self.recording_options.declare('record_residuals', types=bool, default=False,
+                                       desc='Set True to record residuals at the '
+                                            'problem level.')
+        self.recording_options.declare('record_derivatives', types=bool, default=False,
+                                       desc='Set to True to record derivatives for the problem '
+                                            'level')
         self.recording_options.declare('includes', types=list, default=['*'],
                                        desc='Patterns for variables to include in recording. \
                                        Uses fnmatch wildcards')
@@ -459,7 +468,7 @@ class Problem(object):
                 raise TypeError(msg.format(self.msginfo, name, units))
 
             try:
-                scale, offset = get_conversion(units, base_units)
+                scale, offset = unit_conversion(units, base_units)
             except TypeError:
                 msg = "{}: Can't set variable '{}' with units '{}' to value with units '{}'."
                 raise TypeError(msg.format(self.msginfo, name, base_units, units))
@@ -636,6 +645,17 @@ class Problem(object):
         for system in self.model.system_iter(include_self=True, recurse=True):
             system.cleanup()
 
+    def record(self, case_name):
+        """
+        Record the variables at the Problem level.
+
+        Parameters
+        ----------
+        case_name : str
+            Name used to identify this Problem case.
+        """
+        record_iteration(self, self, case_name)
+
     def record_iteration(self, case_name):
         """
         Record the variables at the Problem level.
@@ -645,6 +665,9 @@ class Problem(object):
         case_name : str
             Name used to identify this Problem case.
         """
+        warn_deprecation("'Problem.record_iteration' has been deprecated. "
+                         "Use 'Problem.record' instead.")
+
         record_iteration(self, self, case_name)
 
     def _get_recorder_metadata(self, case_name):
@@ -798,11 +821,6 @@ class Problem(object):
             self._setup_recording()
             record_viewer_data(self)
 
-        # Now that setup has been called, we can set the iprints.
-        for items in self._solver_print_cache:
-            self.set_solver_print(level=items[0], depth=items[1], type_=items[2])
-        self._solver_print_cache = []
-
         if self._setup_status < 2:
             self._setup_status = 2
             self._set_initial_conditions()
@@ -930,7 +948,11 @@ class Problem(object):
         # unless they are in error.
         indep_key = {}
 
+        # Directional derivative directions for matrix free comps.
+        mfree_directions = {}
+
         # Analytic Jacobians
+        print_reverse = False
         for mode in ('fwd', 'rev'):
             model._inputs.set_vec(input_cache)
             model._outputs.set_vec(output_cache)
@@ -948,16 +970,19 @@ class Problem(object):
                 explicit = isinstance(comp, ExplicitComponent)
                 matrix_free = comp.matrix_free
                 c_name = comp.pathname
-                indep_key[c_name] = set()
+                if mode == 'fwd':
+                    indep_key[c_name] = set()
 
                 with comp._unscaled_context():
 
-                    of_list, wrt_list = \
-                        comp._get_potential_partials_lists(include_wrt_outputs=not explicit)
+                    imp = not explicit
+                    of_list, wrt_list = comp._get_potential_partials_lists(include_wrt_outputs=imp)
 
                     # Matrix-free components need to calculate their Jacobian by matrix-vector
                     # product.
                     if matrix_free:
+                        print_reverse = True
+                        local_opts = comp._get_check_partial_options(include_wrt_outputs=imp)
 
                         dstate = comp._vectors['output']['linear']
                         if mode == 'fwd':
@@ -973,6 +998,11 @@ class Problem(object):
 
                         for inp in in_list:
                             inp_abs = rel_name2abs_name(comp, inp)
+                            if mode == 'fwd':
+                                directional = inp in local_opts and \
+                                    local_opts[inp]['directional'] is True
+                            else:
+                                directional = c_name in mfree_directions
 
                             try:
                                 flat_view = dinputs._views_flat[inp_abs]
@@ -980,7 +1010,16 @@ class Problem(object):
                                 # Implicit state
                                 flat_view = dstate._views_flat[inp_abs]
 
-                            n_in = len(flat_view)
+                            if directional:
+                                n_in = 1
+                                perturb = 2.0 * np.random.random(len(flat_view)) - 1.0
+                                if c_name not in mfree_directions:
+                                    mfree_directions[c_name] = {}
+                                mfree_directions[c_name][inp] = perturb
+                            else:
+                                n_in = len(flat_view)
+                                perturb = 1.0
+
                             for idx in range(n_in):
 
                                 dinputs.set_const(0.0)
@@ -988,7 +1027,10 @@ class Problem(object):
 
                                 # Dictionary access returns a scalar for 1d input, and we
                                 # need a vector for clean code, so use _views_flat.
-                                flat_view[idx] = 1.0
+                                if directional:
+                                    flat_view[:] = perturb
+                                else:
+                                    flat_view[idx] = perturb
 
                                 # Matrix Vector Product
                                 comp._apply_linear(None, ['linear'], _contains_all, mode)
@@ -1017,6 +1059,15 @@ class Problem(object):
                                         key = inp, out
                                         deriv = partials_data[c_name][key]
 
+                                        if directional:
+                                            # Dot product test for adjoint validity.
+                                            m = mfree_directions[c_name][out]
+                                            d = mfree_directions[c_name][inp]
+                                            mhat = derivs
+                                            dhat = partials_data[c_name][inp, out]['J_fwd'][:, idx]
+
+                                            deriv['directional_fwd_rev'] = mhat.dot(m) - dhat.dot(d)
+
                                         # Allocate first time
                                         if jac_key not in deriv:
                                             shape = (n_in, len(derivs))
@@ -1026,6 +1077,11 @@ class Problem(object):
 
                     # These components already have a Jacobian with calculated derivatives.
                     else:
+
+                        if mode == 'rev':
+                            # Skip reverse mode because it is not different than forward.
+                            continue
+
                         subjacs = comp._jacobian._subjacs_info
 
                         for rel_key in product(of_list, wrt_list):
@@ -1143,9 +1199,13 @@ class Problem(object):
                             fd_options[name] = value
 
                 all_fd_options[c_name][local_wrt] = fd_options
+                if c_name in mfree_directions:
+                    vector = mfree_directions[c_name].get(local_wrt)
+                else:
+                    vector = None
 
                 approximations[fd_options['method']].add_approximation(abs_key, self.model,
-                                                                       fd_options)
+                                                                       fd_options, vector=vector)
 
             approx_jac = {}
             for approximation in approximations.values():
@@ -1160,8 +1220,17 @@ class Problem(object):
                 wrt = rel_key[1]
                 if wrt in local_opts and local_opts[wrt]['directional']:
                     deriv = partials_data[c_name][rel_key]
-                    for key in ['J_fwd', 'J_rev']:
-                        deriv[key] = np.atleast_2d(np.sum(deriv[key], axis=1)).T
+                    deriv['J_fwd'] = np.atleast_2d(np.sum(deriv['J_fwd'], axis=1)).T
+                    if comp.matrix_free:
+                        deriv['J_rev'] = np.atleast_2d(np.sum(deriv['J_rev'], axis=0)).T
+
+                        # Dot product test for adjoint validity.
+                        m = mfree_directions[c_name][rel_key[0]].flatten()
+                        d = mfree_directions[c_name][wrt].flatten()
+                        mhat = partial.flatten()
+                        dhat = deriv['J_rev'].flatten()
+
+                        deriv['directional_fd_rev'] = dhat.dot(d) - mhat.dot(m)
 
         # Conversion of defaultdict to dicts
         partials_data = {comp_name: dict(outer) for comp_name, outer in partials_data.items()}
@@ -1179,7 +1248,7 @@ class Problem(object):
 
         _assemble_derivative_data(partials_data, rel_err_tol, abs_err_tol, out_stream,
                                   compact_print, comps, all_fd_options, indep_key=indep_key,
-                                  all_comps_provide_jacs=not self.model.matrix_free,
+                                  print_reverse=print_reverse,
                                   show_only_incorrect=show_only_incorrect)
 
         return partials_data
@@ -1292,7 +1361,7 @@ class Problem(object):
             data[''][key] = {}
             data[''][key]['J_fwd'] = val
             data[''][key]['J_fd'] = Jfd[key]
-        fd_args['method'] = 'fd'
+        fd_args['method'] = method
 
         if out_stream == _DEFAULT_OUT_STREAM:
             out_stream = sys.stdout
@@ -1302,7 +1371,7 @@ class Problem(object):
         return data['']
 
     def compute_totals(self, of=None, wrt=None, return_format='flat_dict', debug_print=False,
-                       driver_scaling=False):
+                       driver_scaling=False, use_abs_names=False):
         """
         Compute derivatives of desired quantities with respect to desired inputs.
 
@@ -1324,6 +1393,8 @@ class Problem(object):
             When True, return derivatives that are scaled according to either the adder and scaler
             or the ref and ref0 values that were specified when add_design_var, add_objective, and
             add_constraint were called on the model. Default is False, which is unscaled.
+        use_abs_names : bool
+            Set to True when passing in absolute names to skip some translation steps.
 
         Returns
         -------
@@ -1334,11 +1405,11 @@ class Problem(object):
             self.final_setup()
 
         if self.model._owns_approx_jac:
-            total_info = _TotalJacInfo(self, of, wrt, False, return_format,
+            total_info = _TotalJacInfo(self, of, wrt, use_abs_names, return_format,
                                        approx=True, driver_scaling=driver_scaling)
             return total_info.compute_totals_approx(initialize=True)
         else:
-            total_info = _TotalJacInfo(self, of, wrt, False, return_format,
+            total_info = _TotalJacInfo(self, of, wrt, use_abs_names, return_format,
                                        debug_print=debug_print, driver_scaling=driver_scaling)
             return total_info.compute_totals()
 
@@ -1359,10 +1430,7 @@ class Problem(object):
         type_ : str
             Type of solver to set: 'LN' for linear, 'NL' for nonlinear, or 'all' for all.
         """
-        if (level, depth, type_) not in self._solver_print_cache:
-            self._solver_print_cache.append((level, depth, type_))
-
-        self.model._set_solver_print(level=level, depth=depth, type_=type_)
+        self.model.set_solver_print(level=level, depth=depth, type_=type_)
 
     def list_problem_vars(self,
                           show_promoted_name=True,
@@ -1388,50 +1456,55 @@ class Problem(object):
             List of optional columns to be displayed in the desvars table.
             Allowed values are:
             ['lower', 'upper', 'ref', 'ref0', 'indices', 'adder', 'scaler', 'parallel_deriv_color',
-            'vectorize_derivs', 'cache_linear_solution']
+            'vectorize_derivs', 'cache_linear_solution', 'units']
         cons_opts : list of str
             List of optional columns to be displayed in the cons table.
             Allowed values are:
             ['lower', 'upper', 'equals', 'ref', 'ref0', 'indices', 'index', 'adder', 'scaler',
             'linear', 'parallel_deriv_color', 'vectorize_derivs',
-            'cache_linear_solution']
+            'cache_linear_solution', 'units']
         objs_opts : list of str
             List of optional columns to be displayed in the objs table.
             Allowed values are:
-            ['ref', 'ref0', 'indices', 'adder', 'scaler',
+            ['ref', 'ref0', 'indices', 'adder', 'scaler', 'units',
             'parallel_deriv_color', 'vectorize_derivs', 'cache_linear_solution']
 
         """
         default_col_names = ['name', 'value', 'size']
 
         # Design vars
-        desvars = self.model.get_design_vars()
+        desvars = self.driver._designvars
+        vals = self.driver.get_design_var_values()
         header = "Design Variables"
         col_names = default_col_names + desvar_opts
-        self._write_var_info_table(header, col_names, desvars,
+        self._write_var_info_table(header, col_names, desvars, vals,
                                    show_promoted_name=show_promoted_name,
                                    print_arrays=print_arrays,
                                    col_spacing=2)
 
         # Constraints
-        cons = self.model.get_constraints()
+        cons = self.driver._cons
+        vals = self.driver.get_constraint_values()
         header = "Constraints"
         col_names = default_col_names + cons_opts
-        self._write_var_info_table(header, col_names, cons, show_promoted_name=show_promoted_name,
+        self._write_var_info_table(header, col_names, cons, vals,
+                                   show_promoted_name=show_promoted_name,
                                    print_arrays=print_arrays,
                                    col_spacing=2)
 
-        objs = self.model.get_objectives()
+        objs = self.driver._objs
+        vals = self.driver.get_objective_values()
         header = "Objectives"
         col_names = default_col_names + objs_opts
-        self._write_var_info_table(header, col_names, objs, show_promoted_name=show_promoted_name,
+        self._write_var_info_table(header, col_names, objs, vals,
+                                   show_promoted_name=show_promoted_name,
                                    print_arrays=print_arrays,
                                    col_spacing=2)
 
-    def _write_var_info_table(self, header, col_names, vars, print_arrays=False,
+    def _write_var_info_table(self, header, col_names, meta, vals, print_arrays=False,
                               show_promoted_name=True, col_spacing=1):
         """
-        Write a table of information for the data in vars.
+        Write a table of information for the problem variable in meta and vals.
 
         Parameters
         ----------
@@ -1439,8 +1512,10 @@ class Problem(object):
             The header line for the table.
         col_names : list of str
             List of column labels.
-        vars : OrderedDict
-            Keys are variable names and values are metadata for the variables.
+        meta : OrderedDict
+            Dictionary of metadata for each problem variable.
+        vals : OrderedDict
+            Dictionary of values for each problem variable.
         print_arrays : bool, optional
             When False, in the columnar display, just display norm of any ndarrays with size > 1.
             The norm is surrounded by vertical bars to indicate that it is a norm.
@@ -1456,7 +1531,7 @@ class Problem(object):
 
         # Get the values for all the elements in the tables
         rows = []
-        for name, meta in vars.items():
+        for name, meta in meta.items():
             row = {}
             for col_name in col_names:
                 if col_name == 'name':
@@ -1468,7 +1543,7 @@ class Problem(object):
                         else:
                             row[col_name] = abs2prom['output'][name]
                 elif col_name == 'value':
-                    row[col_name] = self[name]
+                    row[col_name] = vals[name]
                 else:
                     row[col_name] = meta[col_name]
             rows.append(row)
@@ -1585,7 +1660,7 @@ class Problem(object):
 
 def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out_stream,
                               compact_print, system_list, global_options, totals=False,
-                              indep_key=None, all_comps_provide_jacs=False,
+                              indep_key=None, print_reverse=False,
                               show_only_incorrect=False):
     """
     Compute the relative and absolute errors in the given derivatives and print to the out_stream.
@@ -1611,8 +1686,8 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
         Set to True if we are doing check_totals to skip a bunch of stuff.
     indep_key : dict of sets, optional
         Keyed by component name, contains the of/wrt keys that are declared not dependent.
-    all_comps_provide_jacs : bool, optional
-        Set to True if all components provide a Jacobian (are not matrix-free).
+    print_reverse : bool, optional
+        Set to True if compact_print results need to include columns for reverse mode.
     show_only_incorrect : bool, optional
         Set to True if output should print only the subjacs found to be incorrect.
     """
@@ -1620,14 +1695,11 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
     suppress_output = out_stream is None
 
     if compact_print:
-        if totals:
-            deriv_line = "{0} wrt {1} | {2:.4e} | {3:.4e} | {4:.4e} | {5:.4e}"
+        if print_reverse:
+            deriv_line = "{0} wrt {1} | {2:.4e} | {3} | {4:.4e} | {5:.4e} | {6} | {7}" \
+                         " | {8:.4e} | {9} | {10}"
         else:
-            if not all_comps_provide_jacs:
-                deriv_line = "{0} wrt {1} | {2:.4e} | {3} | {4:.4e} | {5:.4e} | {6} | {7}" \
-                             " | {8:.4e} | {9} | {10}"
-            else:
-                deriv_line = "{0} wrt {1} | {2:.4e} | {3:.4e} | {4:.4e} | {5:.4e}"
+            deriv_line = "{0} wrt {1} | {2:.4e} | {3:.4e} | {4:.4e} | {5:.4e}"
 
     # Keep track of the worst subjac in terms of relative error for fwd and rev
     if not suppress_output and compact_print and not totals:
@@ -1642,6 +1714,7 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
 
         sys_name = system.pathname
         sys_class_name = type(system).__name__
+        matrix_free = system.matrix_free
 
         # Match header to appropriate type.
         if isinstance(system, Component):
@@ -1695,7 +1768,7 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                         max_width_of = max(max_width_of, len(of) + 2)  # 2 to include quotes
                         max_width_wrt = max(max_width_wrt, len(wrt) + 2)
 
-                    if not all_comps_provide_jacs:
+                    if print_reverse:
                         header = \
                             "{0} wrt {1} | {2} | {3} | {4} | {5} | {6} | {7} | {8} | {9} | {10}" \
                             .format(
@@ -1721,6 +1794,7 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                                 pad_name('a(fwd-chk)'),
                                 pad_name('r(fwd-chk)'),
                             )
+
                 if out_stream:
                     out_buffer.write(header + '\n')
                     out_buffer.write('-' * len(header) + '\n' + '\n')
@@ -1732,25 +1806,32 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
             else:
                 fd_opts = global_options[sys_name][wrt]
 
+            directional = fd_opts.get('directional')
+            do_rev = not totals and matrix_free and not directional
+            do_rev_dp = not totals and matrix_free and directional
+
             derivative_info = derivatives[of, wrt]
             forward = derivative_info['J_fwd']
-            if not totals:
-                reverse = derivative_info.get('J_rev')
             fd = derivative_info['J_fd']
+            if do_rev:
+                reverse = derivative_info.get('J_rev')
 
             fwd_error = np.linalg.norm(forward - fd)
-            if totals:
-                rev_error = fwd_rev_error = None
-            else:
+            if do_rev_dp:
+                fwd_rev_error = derivative_info['directional_fwd_rev']
+                rev_error = derivative_info['directional_fd_rev']
+            elif do_rev:
                 rev_error = np.linalg.norm(reverse - fd)
                 fwd_rev_error = np.linalg.norm(forward - reverse)
+            else:
+                rev_error = fwd_rev_error = None
 
             fwd_norm = np.linalg.norm(forward)
-            if totals:
-                rev_norm = None
-            else:
-                rev_norm = np.linalg.norm(reverse)
             fd_norm = np.linalg.norm(fd)
+            if do_rev:
+                rev_norm = np.linalg.norm(reverse)
+            else:
+                rev_norm = None
 
             derivative_info['abs error'] = abs_err = ErrorTuple(fwd_error, rev_error, fwd_rev_error)
             derivative_info['magnitude'] = magnitude = MagnitudeTuple(fwd_norm, rev_norm, fd_norm)
@@ -1762,25 +1843,25 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                 else:
                     # If fd_norm is zero, let's use fwd_norm as the divisor for relative
                     # check. That way we don't accidentally squelch a legitimate problem.
-                    if totals:
-                        derivative_info['rel error'] = rel_err = ErrorTuple(fwd_error / fwd_norm,
-                                                                            nan,
-                                                                            nan)
-                    else:
+                    if do_rev or do_rev_dp:
                         rel_err = ErrorTuple(fwd_error / fwd_norm,
                                              rev_error / fwd_norm,
                                              fwd_rev_error / fwd_norm)
                         derivative_info['rel error'] = rel_err
+                    else:
+                        derivative_info['rel error'] = rel_err = ErrorTuple(fwd_error / fwd_norm,
+                                                                            None,
+                                                                            None)
 
             else:
-                if totals:
-                    derivative_info['rel error'] = rel_err = ErrorTuple(fwd_error / fd_norm,
-                                                                        nan,
-                                                                        nan)
-                else:
+                if do_rev or do_rev_dp:
                     derivative_info['rel error'] = rel_err = ErrorTuple(fwd_error / fd_norm,
                                                                         rev_error / fd_norm,
                                                                         fwd_rev_error / fd_norm)
+                else:
+                    derivative_info['rel error'] = rel_err = ErrorTuple(fwd_error / fd_norm,
+                                                                        None,
+                                                                        None)
 
             # Skip printing the dependent keys if the derivatives are fine.
             if not compact_print and indep_key is not None:
@@ -1790,12 +1871,11 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                     continue
 
             if not suppress_output:
-                directional = fd_opts.get('directional')
 
                 if compact_print:
                     if totals:
                         if out_stream:
-                            out_stream.write(deriv_line.format(
+                            out_buffer.write(deriv_line.format(
                                 pad_name(of, 30, quotes=True),
                                 pad_name(wrt, 30, quotes=True),
                                 magnitude.forward,
@@ -1806,6 +1886,8 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                     else:
                         error_string = ''
                         for error in abs_err:
+                            if error is None:
+                                continue
                             if not np.isnan(error) and error >= abs_error_tol:
                                 error_string += ' >ABS_TOL'
                                 break
@@ -1815,6 +1897,8 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                         # compared to the other components so far
                         is_worst_subjac = False
                         for i, error in enumerate(rel_err):
+                            if error is None:
+                                continue
                             if not np.isnan(error):
                                 #  only 1st and 2d errs
                                 if i < 2 and error > worst_subjac_rel_err:
@@ -1835,25 +1919,25 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                                 wrt_padded = pad_name(wrt, max_width_wrt, quotes=False)
                             else:
                                 wrt_padded = pad_name(wrt, max_width_wrt, quotes=True)
-                            if not all_comps_provide_jacs:
+                            if print_reverse:
                                 deriv_info_line = \
                                     deriv_line.format(
                                         pad_name(of, max_width_of, quotes=True),
                                         wrt_padded,
                                         magnitude.forward,
-                                        _format_if_not_matrix_free(
-                                            system.matrix_free, magnitude.reverse),
+                                        _format_if_not_matrix_free(matrix_free and not directional,
+                                                                   magnitude.reverse),
                                         magnitude.fd,
                                         abs_err.forward,
-                                        _format_if_not_matrix_free(system.matrix_free,
+                                        _format_if_not_matrix_free(matrix_free,
                                                                    abs_err.reverse),
-                                        _format_if_not_matrix_free(
-                                            system.matrix_free, abs_err.forward_reverse),
+                                        _format_if_not_matrix_free(matrix_free,
+                                                                   abs_err.forward_reverse),
                                         rel_err.forward,
-                                        _format_if_not_matrix_free(system.matrix_free,
+                                        _format_if_not_matrix_free(matrix_free,
                                                                    rel_err.reverse),
-                                        _format_if_not_matrix_free(
-                                            system.matrix_free, rel_err.forward_reverse),
+                                        _format_if_not_matrix_free(matrix_free,
+                                                                   rel_err.forward_reverse),
                                     )
                             else:
                                 deriv_info_line = \
@@ -1882,18 +1966,23 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                             out_buffer.write("  {}: '{}' wrt '{}'\n".format(sys_name, of, wrt))
                         out_buffer.write('    Forward Magnitude : {:.6e}\n'.format(
                             magnitude.forward))
-                    if not totals and system.matrix_free:
+                    if do_rev:
                         txt = '    Reverse Magnitude : {:.6e}'
                         if out_stream:
                             out_buffer.write(txt.format(magnitude.reverse) + '\n')
                     if out_stream:
                         out_buffer.write('         Fd Magnitude : {:.6e} ({})\n'.format(
                             magnitude.fd, fd_desc))
+
                     # Absolute Errors
-                    if totals or not system.matrix_free:
-                        error_descs = ('(Jfor  - Jfd) ', )
-                    else:
+                    if do_rev:
                         error_descs = ('(Jfor  - Jfd) ', '(Jrev  - Jfd) ', '(Jfor  - Jrev)')
+                    elif do_rev_dp:
+                        error_descs = ('(Jfor  - Jfd) ', '(Jrev - Jfd  Dot Product Test) ',
+                                       '(Jrev - Jfor Dot Product Test) ')
+                    else:
+                        error_descs = ('(Jfor  - Jfd) ', )
+
                     for error, desc in zip(abs_err, error_descs):
                         error_str = _format_error(error, abs_error_tol)
                         if error_str.endswith('*'):
@@ -1904,6 +1993,9 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                         out_buffer.write('\n')
 
                     # Relative Errors
+                    if do_rev_dp:
+                        error_descs = ('(Jfor  - Jfd) ', )
+
                     for error, desc in zip(rel_err, error_descs):
                         error_str = _format_error(error, rel_error_tol)
                         if error_str.endswith('*'):
@@ -1918,21 +2010,19 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
 
                     # Raw Derivatives
                     if out_stream:
-                        if directional:
+                        if do_rev_dp:
                             out_buffer.write('    Directional Forward Derivative (Jfor)\n')
                         else:
                             out_buffer.write('    Raw Forward Derivative (Jfor)\n')
                         out_buffer.write(str(forward) + '\n')
                         out_buffer.write('\n')
 
-                    if not totals and system.matrix_free:
+                    if not totals and matrix_free:
                         if out_stream:
-                            if directional:
-                                out_buffer.write('    Directional Reverse Derivative (Jrev)\n')
-                            else:
+                            if not directional:
                                 out_buffer.write('    Raw Reverse Derivative (Jrev)\n')
-                            out_buffer.write(str(reverse) + '\n')
-                            out_buffer.write('\n')
+                                out_buffer.write(str(reverse) + '\n')
+                                out_buffer.write('\n')
 
                     if out_stream:
                         if directional:
