@@ -7,7 +7,7 @@ import numpy as np
 import openmdao.api as om
 from openmdao.core.system import get_relevant_vars
 from openmdao.core.driver import Driver
-from openmdao.utils.assert_utils import assert_rel_error, assert_warning
+from openmdao.utils.assert_utils import assert_near_equal, assert_warning
 from openmdao.test_suite.components.paraboloid import Paraboloid
 from openmdao.test_suite.components.sellar import SellarDerivatives
 
