@@ -5,12 +5,14 @@ import numpy as np
 
 from openmdao.api import Problem, NonlinearBlockGS, Group, IndepVarComp, ExecComp, ScipyKrylov,  \
     IndepVarComp, ScipyOptimizeDriver
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 from openmdao.utils.mpi import MPI
 
 from openmdao.test_suite.components.sellar import SellarDerivatives, SellarDis1withDerivatives, \
      SellarDis2withDerivatives
 
+from openmdao.core.tests.test_distribcomp import DistribInputDistribOutputComp
+
 try:
     from openmdao.vectors.petsc_vector import PETScVector
 except ImportError:
@@ -351,6 +353,23 @@ class TestConstraintOnModel(unittest.TestCase):
 
         self.assertEqual(str(context.exception), "SellarDerivatives (<model>): Output not found for response 'junk'.")
 
+    def test_constraint_on_distrib_output(self):
+        # this test should be removed once distributed outputs are able to be used as constraints
+        # this tests a temporary fix for issue #1331
+        prob = Problem()
+        model = Group()
+        model.add_subsystem('dvs', IndepVarComp('x', val=1.0*np.ones((2,))))
+        model.add_subsystem('distcomp', DistribInputDistribOutputComp(arr_size=2))
+        model.add_subsystem('sum', ExecComp('y = sum(x)', x=np.ones((2,))))
+        model.connect('dvs.x', 'distcomp.invec')
+        model.connect('distcomp.outvec', 'sum.x')
+        prob.model = model
+        prob.model.add_design_var('dvs.x', lower=-100, upper=100)
+        prob.model.add_objective('sum.y')
+        prob.model.add_constraint('distcomp.outvec', lower=-10.5)
+        with self.assertRaises(NotImplementedError) as context:
+            prob.setup()
+
     def test_constraint_affine_and_scaleradder(self):
 
         prob = Problem()
