@@ -1,4 +1,3 @@
-from __future__ import print_function
 
 import unittest
 import time
@@ -8,7 +7,7 @@ import numpy as np
 import openmdao.api as om
 from openmdao.utils.mpi import MPI
 from openmdao.utils.array_utils import evenly_distrib_idxs, take_nth
-from openmdao.utils.assert_utils import assert_rel_error, assert_warning
+from openmdao.utils.assert_utils import assert_near_equal, assert_warning
 
 try:
     from openmdao.vectors.petsc_vector import PETScVector
@@ -182,6 +181,46 @@ class DistribInputDistribOutputComp(om.ExplicitComponent):
         self.add_output('outvec', np.ones(sizes[rank], float))
 
 
+class DistribCompWithDerivs(om.ExplicitComponent):
+    """Uses 2 procs and takes input var slices, but also computes partials"""
+
+    def initialize(self):
+        self.options['distributed'] = True
+
+        self.options.declare('arr_size', types=int, default=11,
+                             desc="Size of input and output vectors.")
+
+    def compute(self, inputs, outputs):
+        outputs['outvec'] = inputs['invec']*2.0
+
+    def compute_partials(self, inputs, J):
+        sizes = self.sizes
+        comm = self.comm
+        rank = comm.rank
+
+        J['outvec', 'invec'] = 2.0 * np.ones((sizes[rank],))
+
+    def setup(self):
+
+        comm = self.comm
+        rank = comm.rank
+
+        arr_size = self.options['arr_size']
+
+        sizes, offsets = evenly_distrib_idxs(comm.size, arr_size)
+        self.sizes = sizes
+        self.offsets = offsets
+
+        start = offsets[rank]
+        end = start + sizes[rank]
+
+        # don't set src_indices on the input and just use default behavior
+        self.add_input('invec', np.ones(sizes[rank], float))
+        self.add_output('outvec', np.ones(sizes[rank], float))
+        self.declare_partials('outvec', 'invec', rows=np.arange(0, sizes[rank]),
+                                                 cols=np.arange(0, sizes[rank]))
+
+
 class DistribInputDistribOutputDiscreteComp(DistribInputDistribOutputComp):
 
     def compute(self, inputs, outputs, discrete_inputs, discrete_outputs):
@@ -328,6 +367,29 @@ class MPITests(unittest.TestCase):
 
         self.assertTrue(all(C2._outputs['outvec'] == np.ones(size, float)*7.5))
 
+    def test_distrib_check_partials(self):
+        # will produce uneven array sizes which we need for the test
+        size = 11
+
+        p = om.Problem()
+        top = p.model
+        C1 = top.add_subsystem("C1", InOutArrayComp(arr_size=size))
+        C2 = top.add_subsystem("C2", DistribCompWithDerivs(arr_size=size))
+        top.connect('C1.outvec', 'C2.invec')
+
+        p.setup()
+
+        # Conclude setup but don't run model.
+        p.final_setup()
+
+        # run the model and check partials
+        p.run_model()
+
+        # this used to fail (bug #1279)
+        cpd = p.check_partials(out_stream=None)
+        for (of, wrt) in cpd['C2']:
+            np.testing.assert_almost_equal(cpd['C2'][of, wrt]['rel error'][0], 0.0, decimal=5)
+
     def test_list_inputs_outputs(self):
         size = 11
 
@@ -609,82 +671,6 @@ class MPITests(unittest.TestCase):
             self.assertTrue(all(C3._outputs['outvec'] == np.array(range(size, 0, -1), float)*4))
 
 
-@unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
-class DeprecatedMPITests(unittest.TestCase):
-
-    N_PROCS = 2
-
-    def test_distrib_idx_in_full_out_deprecated(self):
-
-        class DeprecatedDistribInputComp(om.ExplicitComponent):
-            """Deprecated version of DistribInputComp, uses attribute instead of option."""
-
-            def __init__(self, arr_size=11):
-                super(DeprecatedDistribInputComp, self).__init__()
-                self.arr_size = arr_size
-                self.distributed = True
-
-            def compute(self, inputs, outputs):
-                if MPI:
-                    self.comm.Allgatherv(inputs['invec']*2.0,
-                                         [outputs['outvec'], self.sizes,
-                                          self.offsets, MPI.DOUBLE])
-                else:
-                    outputs['outvec'] = inputs['invec'] * 2.0
-
-            def setup(self):
-                comm = self.comm
-                rank = comm.rank
-
-                self.sizes, self.offsets = evenly_distrib_idxs(comm.size, self.arr_size)
-                start = self.offsets[rank]
-                end = start + self.sizes[rank]
-
-                self.add_input('invec', np.ones(self.sizes[rank], float),
-                               src_indices=np.arange(start, end, dtype=int))
-                self.add_output('outvec', np.ones(self.arr_size, float),
-                                shape=np.int32(self.arr_size))
-
-        size = 11
-
-        p = om.Problem()
-        top = p.model
-
-        C1 = top.add_subsystem("C1", InOutArrayComp(arr_size=size))
-
-        # check deprecation on setter & getter
-        msg = "The 'distributed' property provides backwards compatibility " \
-              "with OpenMDAO <= 2.4.0 ; use the 'distributed' option instead."
-
-        with assert_warning(DeprecationWarning, msg):
-            C2 = top.add_subsystem("C2", DeprecatedDistribInputComp(arr_size=size))
-
-        with assert_warning(DeprecationWarning, msg):
-            C2.distributed
-
-        # continue to make sure everything still works with the deprecation
-        top.connect('C1.outvec', 'C2.invec')
-
-        # Conclude setup but don't run model.
-        msg = "The 'distributed' option is set to True for Component C2, " \
-              "but there is no distributed vector implementation (MPI/PETSc) " \
-              "available. The default non-distributed vectors will be used."
-
-        if PETScVector is None:
-            with assert_warning(UserWarning, msg):
-                p.setup()
-        else:
-            p.setup()
-
-        p.final_setup()
-
-        C1._inputs['invec'] = np.array(range(size, 0, -1), float)
-
-        p.run_model()
-
-        self.assertTrue(all(C2._outputs['outvec'] == np.array(range(size, 0, -1), float)*4))
-
-
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
 class ProbRemoteTests(unittest.TestCase):
 
@@ -854,11 +840,11 @@ class MPIFeatureTests(unittest.TestCase):
         prob['indep.x'] = np.ones(size)
         prob.run_model()
 
-        assert_rel_error(self, prob['C2.invec'],
-                         np.ones((8,)) if model.comm.rank == 0 else np.ones((7,)))
-        assert_rel_error(self, prob['C2.outvec'],
-                         2*np.ones((8,)) if model.comm.rank == 0 else -3*np.ones((7,)))
-        assert_rel_error(self, prob['C3.out'], -5.)
+        assert_near_equal(prob['C2.invec'],
+                          np.ones((8,)) if model.comm.rank == 0 else np.ones((7,)))
+        assert_near_equal(prob['C2.outvec'],
+                          2*np.ones((8,)) if model.comm.rank == 0 else -3*np.ones((7,)))
+        assert_near_equal(prob['C3.sum'], -5.)
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
@@ -898,12 +884,12 @@ class TestGroupMPI(unittest.TestCase):
         p.run_model()
 
         # each rank holds the assigned portion of the input array
-        assert_rel_error(self, p['C1.x'],
+        assert_near_equal(p['C1.x'],
                          np.arange(3, dtype=float) if p.model.C1.comm.rank == 0 else
                          np.arange(3, 5, dtype=float))
 
         # the output in each rank is based on the local inputs
-        assert_rel_error(self, p['C1.y'], 6. if p.model.C1.comm.rank == 0 else 14.)
+        assert_near_equal(p['C1.y'], 6. if p.model.C1.comm.rank == 0 else 14.)
 
 
 if __name__ == '__main__':
