@@ -14,7 +14,7 @@ from scipy.sparse import coo_matrix
 
 from openmdao.api import Problem, Group, IndepVarComp, ImplicitComponent, ExecComp, \
     ExplicitComponent, NonlinearBlockGS, ScipyOptimizeDriver
-from openmdao.utils.assert_utils import assert_rel_error, assert_warning
+from openmdao.utils.assert_utils import assert_near_equal, assert_warning
 from openmdao.utils.array_utils import evenly_distrib_idxs
 from openmdao.utils.mpi import MPI
 from openmdao.utils.coloring import compute_total_coloring, Coloring
@@ -669,7 +669,6 @@ class TestColoring(unittest.TestCase):
 
         self.assertEqual(comp._coloring_info['coloring'], None)
         self.assertEqual(comp._coloring_info['static'], None)
-        self.assertEqual(comp._coloring_info['dynamic'], None)
 
         jac = comp._jacobian._subjacs_info
         _check_partial_matrix(comp, jac, sparsity, 'cs')
@@ -717,7 +716,6 @@ class TestColoring(unittest.TestCase):
             self.assertEqual(6, comp._nruns - start_nruns)
             self.assertEqual(comp._coloring_info['coloring'], None)
             self.assertEqual(comp._coloring_info['static'], None)
-            self.assertEqual(comp._coloring_info['dynamic'], None)
 
             jac = comp._jacobian._subjacs_info
             _check_partial_matrix(comp, jac, sparsity, 'cs')
