@@ -27,7 +27,7 @@ except ImportError:
 from openmdao.test_suite.groups.parallel_groups import \
     FanOutGrouped, FanInGrouped2, Diamond, ConvergeDiverge
 
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 from openmdao.utils.logger_utils import TestLogger
 from openmdao.error_checking.check_config import _default_checks
 
@@ -81,22 +81,22 @@ class TestParallelGroups(unittest.TestCase):
 
         J = prob.compute_totals(of=['c2.y', "c3.y"], wrt=['iv.x'])
 
-        assert_rel_error(self, J['c2.y', 'iv.x'][0][0], -6.0, 1e-6)
-        assert_rel_error(self, J['c3.y', 'iv.x'][0][0], 15.0, 1e-6)
+        assert_near_equal(J['c2.y', 'iv.x'][0][0], -6.0, 1e-6)
+        assert_near_equal(J['c3.y', 'iv.x'][0][0], 15.0, 1e-6)
 
-        assert_rel_error(self, prob['c2.y'], -6.0, 1e-6)
-        assert_rel_error(self, prob['c3.y'], 15.0, 1e-6)
+        assert_near_equal(prob['c2.y'], -6.0, 1e-6)
+        assert_near_equal(prob['c3.y'], 15.0, 1e-6)
 
         prob.setup(check=False, mode='rev')
         prob.run_model()
 
         J = prob.compute_totals(of=['c2.y', "c3.y"], wrt=['iv.x'])
 
-        assert_rel_error(self, J['c2.y', 'iv.x'][0][0], -6.0, 1e-6)
-        assert_rel_error(self, J['c3.y', 'iv.x'][0][0], 15.0, 1e-6)
+        assert_near_equal(J['c2.y', 'iv.x'][0][0], -6.0, 1e-6)
+        assert_near_equal(J['c3.y', 'iv.x'][0][0], 15.0, 1e-6)
 
-        assert_rel_error(self, prob['c2.y'], -6.0, 1e-6)
-        assert_rel_error(self, prob['c3.y'], 15.0, 1e-6)
+        assert_near_equal(prob['c2.y'], -6.0, 1e-6)
+        assert_near_equal(prob['c3.y'], 15.0, 1e-6)
 
     @parameterized.expand(itertools.product([om.LinearRunOnce],
                                             [om.NonlinearBlockGS, om.NonlinearRunOnce]),
@@ -116,34 +116,34 @@ class TestParallelGroups(unittest.TestCase):
         indep_list = ['p1.x', 'p2.x']
         unknown_list = ['c3.y']
 
-        assert_rel_error(self, prob['c3.y'], 29.0, 1e-6)
+        assert_near_equal(prob['c3.y'], 29.0, 1e-6)
 
         J = prob.compute_totals(of=unknown_list, wrt=indep_list)
-        assert_rel_error(self, J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
-        assert_rel_error(self, J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
+        assert_near_equal(J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
+        assert_near_equal(J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
 
         # do this a second time to test caching of dist rows/cols
         J = prob.compute_totals(of=unknown_list, wrt=indep_list)
-        assert_rel_error(self, J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
-        assert_rel_error(self, J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
+        assert_near_equal(J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
+        assert_near_equal(J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
 
-        assert_rel_error(self, prob['c3.y'], 29.0, 1e-6)
+        assert_near_equal(prob['c3.y'], 29.0, 1e-6)
 
         prob.setup(check=False, mode='rev')
         prob.run_model()
 
-        assert_rel_error(self, prob['c3.y'], 29.0, 1e-6)
+        assert_near_equal(prob['c3.y'], 29.0, 1e-6)
 
         J = prob.compute_totals(of=unknown_list, wrt=indep_list)
-        assert_rel_error(self, J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
-        assert_rel_error(self, J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
+        assert_near_equal(J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
+        assert_near_equal(J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
 
         # do this a second time to test caching of dist rows/cols
         J = prob.compute_totals(of=unknown_list, wrt=indep_list)
-        assert_rel_error(self, J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
-        assert_rel_error(self, J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
+        assert_near_equal(J['c3.y', 'p1.x'][0][0], -6.0, 1e-6)
+        assert_near_equal(J['c3.y', 'p2.x'][0][0], 35.0, 1e-6)
 
-        assert_rel_error(self, prob['c3.y'], 29.0, 1e-6)
+        assert_near_equal(prob['c3.y'], 29.0, 1e-6)
 
     def test_fan_in_grouped_feature(self):
 
@@ -170,7 +170,7 @@ class TestParallelGroups(unittest.TestCase):
         prob.setup(check=False, mode='fwd')
         prob.run_model()
 
-        assert_rel_error(self, prob['c3.y'], 29.0, 1e-6)
+        assert_near_equal(prob['c3.y'], 29.0, 1e-6)
 
     @parameterized.expand(itertools.product([om.LinearRunOnce],
                                             [om.NonlinearBlockGS, om.NonlinearRunOnce]),
@@ -187,25 +187,25 @@ class TestParallelGroups(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['c4.y1'], 46.0, 1e-6)
-        assert_rel_error(self, prob['c4.y2'], -93.0, 1e-6)
+        assert_near_equal(prob['c4.y1'], 46.0, 1e-6)
+        assert_near_equal(prob['c4.y2'], -93.0, 1e-6)
 
         indep_list = ['iv.x']
         unknown_list = ['c4.y1', 'c4.y2']
 
         J = prob.compute_totals(of=unknown_list, wrt=indep_list)
-        assert_rel_error(self, J['c4.y1', 'iv.x'][0][0], 25, 1e-6)
-        assert_rel_error(self, J['c4.y2', 'iv.x'][0][0], -40.5, 1e-6)
+        assert_near_equal(J['c4.y1', 'iv.x'][0][0], 25, 1e-6)
+        assert_near_equal(J['c4.y2', 'iv.x'][0][0], -40.5, 1e-6)
 
         prob.setup(check=False, mode='rev')
         prob.run_model()
 
-        assert_rel_error(self, prob['c4.y1'], 46.0, 1e-6)
-        assert_rel_error(self, prob['c4.y2'], -93.0, 1e-6)
+        assert_near_equal(prob['c4.y1'], 46.0, 1e-6)
+        assert_near_equal(prob['c4.y2'], -93.0, 1e-6)
 
         J = prob.compute_totals(of=unknown_list, wrt=indep_list)
-        assert_rel_error(self, J['c4.y1', 'iv.x'][0][0], 25, 1e-6)
-        assert_rel_error(self, J['c4.y2', 'iv.x'][0][0], -40.5, 1e-6)
+        assert_near_equal(J['c4.y1', 'iv.x'][0][0], 25, 1e-6)
+        assert_near_equal(J['c4.y2', 'iv.x'][0][0], -40.5, 1e-6)
 
     @parameterized.expand(itertools.product([om.LinearRunOnce],
                                             [om.NonlinearBlockGS, om.NonlinearRunOnce]),
@@ -222,23 +222,23 @@ class TestParallelGroups(unittest.TestCase):
         prob.set_solver_print(level=0)
         prob.run_model()
 
-        assert_rel_error(self, prob['c7.y1'], -102.7, 1e-6)
+        assert_near_equal(prob['c7.y1'], -102.7, 1e-6)
 
         indep_list = ['iv.x']
         unknown_list = ['c7.y1']
 
         J = prob.compute_totals(of=unknown_list, wrt=indep_list)
-        assert_rel_error(self, J['c7.y1', 'iv.x'][0][0], -40.75, 1e-6)
+        assert_near_equal(J['c7.y1', 'iv.x'][0][0], -40.75, 1e-6)
 
         prob.setup(check=False, mode='rev')
         prob.run_model()
 
-        assert_rel_error(self, prob['c7.y1'], -102.7, 1e-6)
+        assert_near_equal(prob['c7.y1'], -102.7, 1e-6)
 
         J = prob.compute_totals(of=unknown_list, wrt=indep_list)
-        assert_rel_error(self, J['c7.y1', 'iv.x'][0][0], -40.75, 1e-6)
+        assert_near_equal(J['c7.y1', 'iv.x'][0][0], -40.75, 1e-6)
 
-        assert_rel_error(self, prob['c7.y1'], -102.7, 1e-6)
+        assert_near_equal(prob['c7.y1'], -102.7, 1e-6)
 
     def test_zero_shape(self):
         raise unittest.SkipTest("zero shapes not fully supported yet")
@@ -291,22 +291,22 @@ class TestParallelGroups(unittest.TestCase):
 
         J = prob.compute_totals(of=['c2.y', "c3.y"], wrt=['iv.x'])
 
-        assert_rel_error(self, J['c2.y', 'iv.x'][0][0], -6.0, 1e-6)
-        assert_rel_error(self, J['c3.y', 'iv.x'][0][0], 15.0, 1e-6)
+        assert_near_equal(J['c2.y', 'iv.x'][0][0], -6.0, 1e-6)
+        assert_near_equal(J['c3.y', 'iv.x'][0][0], 15.0, 1e-6)
 
-        assert_rel_error(self, prob['c2.y'], -6.0, 1e-6)
-        assert_rel_error(self, prob['c3.y'], 15.0, 1e-6)
+        assert_near_equal(prob['c2.y'], -6.0, 1e-6)
+        assert_near_equal(prob['c3.y'], 15.0, 1e-6)
 
         prob.setup(check=False, mode='rev')
         prob.run_model()
 
         J = prob.compute_totals(of=['c2.y', "c3.y"], wrt=['iv.x'])
 
-        assert_rel_error(self, J['c2.y', 'iv.x'][0][0], -6.0, 1e-6)
-        assert_rel_error(self, J['c3.y', 'iv.x'][0][0], 15.0, 1e-6)
+        assert_near_equal(J['c2.y', 'iv.x'][0][0], -6.0, 1e-6)
+        assert_near_equal(J['c3.y', 'iv.x'][0][0], 15.0, 1e-6)
 
-        assert_rel_error(self, prob['c2.y'], -6.0, 1e-6)
-        assert_rel_error(self, prob['c3.y'], 15.0, 1e-6)
+        assert_near_equal(prob['c2.y'], -6.0, 1e-6)
+        assert_near_equal(prob['c3.y'], 15.0, 1e-6)
 
     def test_setup_messages_bad_vec_type(self):
 
