@@ -12,7 +12,7 @@ import openmdao.api as om
 from openmdao.test_suite.components.paraboloid import Paraboloid
 from openmdao.test_suite.components.expl_comp_array import TestExplCompArrayDense
 from openmdao.test_suite.components.sellar import SellarDerivativesGrouped
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 from openmdao.utils.general_utils import set_pyoptsparse_opt, run_driver
 from openmdao.utils.testing_utils import use_tempdirs
 from openmdao.utils.mpi import MPI
@@ -143,6 +143,7 @@ class DataSave(om.ExplicitComponent):
 
         partials['y', 'x'] = 2.0*x - 6.0
 
+
 @unittest.skipIf(OPT is None or OPTIMIZER is None, "only run if pyoptsparse is installed.")
 @unittest.skipUnless(MPI, "MPI is required.")
 class TestMPIScatter(unittest.TestCase):
@@ -175,6 +176,7 @@ class TestMPIScatter(unittest.TestCase):
         proc_vals = MPI.COMM_WORLD.allgather([prob['x'], prob['y'], prob['c'], prob['f_xy']])
         np.testing.assert_array_almost_equal(proc_vals[0], proc_vals[1])
 
+
 @unittest.skipIf(OPT is None or OPTIMIZER is None, "only run if pyoptsparse is installed.")
 @use_tempdirs
 class TestPyoptSparse(unittest.TestCase):
@@ -208,8 +210,8 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-6)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-6)
+        assert_near_equal(prob['x'], 7.16667, 1e-6)
+        assert_near_equal(prob['y'], -7.833334, 1e-6)
 
     def test_simple_paraboloid_upper_indices(self):
 
@@ -252,8 +254,8 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['p1.x'], np.array([50., 7.16667, 50.]), 1e-6)
-        assert_rel_error(self, prob['p2.y'], np.array([50., -7.833334, 50.]), 1e-6)
+        assert_near_equal(prob['p1.x'], np.array([50., 7.16667, 50.]), 1e-6)
+        assert_near_equal(prob['p2.y'], np.array([50., -7.833334, 50.]), 1e-6)
 
     def test_simple_paraboloid_lower(self):
 
@@ -287,8 +289,8 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-6)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-6)
+        assert_near_equal(prob['x'], 7.16667, 1e-6)
+        assert_near_equal(prob['y'], -7.833334, 1e-6)
 
     def test_simple_paraboloid_lower_linear(self):
 
@@ -321,8 +323,8 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-6)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-6)
+        assert_near_equal(prob['x'], 7.16667, 1e-6)
+        assert_near_equal(prob['y'], -7.833334, 1e-6)
 
         self.assertEqual(prob.driver._quantities, ['comp.f_xy'])
 
@@ -363,8 +365,8 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-6)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-6)
+        assert_near_equal(prob['x'], 7.16667, 1e-6)
+        assert_near_equal(prob['y'], -7.833334, 1e-6)
 
     def test_simple_paraboloid_equality_linear(self):
 
@@ -397,8 +399,8 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-6)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-6)
+        assert_near_equal(prob['x'], 7.16667, 1e-6)
+        assert_near_equal(prob['y'], -7.833334, 1e-6)
 
     def test_simple_paraboloid_double_sided_low(self):
 
@@ -429,7 +431,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['y'] - prob['x'], -11.0, 1e-6)
+        assert_near_equal(prob['y'] - prob['x'], -11.0, 1e-6)
 
     def test_simple_paraboloid_double_sided_high(self):
 
@@ -460,7 +462,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_simple_array_comp2D(self):
 
@@ -492,7 +494,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         obj = prob['o']
-        assert_rel_error(self, obj, 20.0, 1e-6)
+        assert_near_equal(obj, 20.0, 1e-6)
 
     def test_simple_array_comp2D_array_lo_hi(self):
 
@@ -524,7 +526,26 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         obj = prob['o']
-        assert_rel_error(self, obj, 20.0, 1e-6)
+        assert_near_equal(obj, 20.0, 1e-6)
+
+    def test_driver_supports(self):
+
+        prob = om.Problem()
+        model = prob.model
+
+        model.add_subsystem('p1', om.IndepVarComp('x', 50.0), promotes=['*'])
+
+        prob.driver = pyOptSparseDriver(optimizer=OPTIMIZER, print_results=False)
+
+        with self.assertRaises(KeyError) as raises_msg:
+            prob.driver.supports['equality_constraints'] = False
+
+        exception = raises_msg.exception
+
+        msg = "pyOptSparseDriver: Tried to set read-only option 'equality_constraints'."
+
+        self.assertEqual(exception.args[0], msg)
+
 
     def test_fan_out(self):
         # This tests sparse-response specification.
@@ -571,7 +592,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         obj = prob['obj.o']
-        assert_rel_error(self, obj, 30.0, 1e-6)
+        assert_near_equal(obj, 30.0, 1e-6)
 
         # Verify that pyOpt has the correct wrt names
         con1 = prob.driver.pyopt_solution.constraints['con1.c']
@@ -613,8 +634,8 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-6)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-6)
+        assert_near_equal(prob['x'], 7.16667, 1e-6)
+        assert_near_equal(prob['y'], -7.833334, 1e-6)
 
     def test_pyopt_fd_solution(self):
 
@@ -648,8 +669,8 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-4)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-4)
+        assert_near_equal(prob['x'], 7.16667, 1e-4)
+        assert_near_equal(prob['y'], -7.833334, 1e-4)
 
     def test_pyopt_fd_is_called(self):
 
@@ -688,8 +709,8 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-4)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-4)
+        assert_near_equal(prob['x'], 7.16667, 1e-4)
+        assert_near_equal(prob['y'], -7.833334, 1e-4)
 
     def test_snopt_fd_option_error(self):
 
@@ -793,7 +814,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_simple_paraboloid_scaled_desvars_fd(self):
         prob = om.Problem()
@@ -827,7 +848,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_simple_paraboloid_scaled_desvars_cs(self):
         prob = om.Problem()
@@ -861,7 +882,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_simple_paraboloid_scaled_desvars_rev(self):
 
@@ -894,7 +915,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_simple_paraboloid_scaled_constraint_fwd(self):
 
@@ -927,7 +948,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_simple_paraboloid_scaled_constraint_fd(self):
         prob = om.Problem()
@@ -961,7 +982,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_simple_paraboloid_scaled_constraint_cs(self):
         prob = om.Problem()
@@ -995,7 +1016,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_simple_paraboloid_scaled_constraint_rev(self):
 
@@ -1028,7 +1049,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_simple_paraboloid_scaled_objective_fwd(self):
 
@@ -1061,7 +1082,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_simple_paraboloid_scaled_objective_rev(self):
 
@@ -1094,7 +1115,7 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'] - prob['y'], 11.0, 1e-6)
+        assert_near_equal(prob['x'] - prob['y'], 11.0, 1e-6)
 
     def test_sellar_mdf(self):
 
@@ -1122,9 +1143,9 @@ class TestPyoptSparse(unittest.TestCase):
         self.assertFalse(failed, "Optimization failed, info = " +
                                  str(prob.driver.pyopt_solution.optInform))
 
-        assert_rel_error(self, prob['z'][0], 1.9776, 1e-3)
-        assert_rel_error(self, prob['z'][1], 0.0, 1e-3)
-        assert_rel_error(self, prob['x'], 0.0, 4e-3)
+        assert_near_equal(prob['z'][0], 1.9776, 1e-3)
+        assert_near_equal(prob['z'][1], 0.0, 1e-3)
+        assert_near_equal(prob['x'], 0.0, 4e-3)
 
     def test_sellar_mdf_linear_con_directsolver(self):
         # This test makes sure that we call solve_nonlinear first if we have any linear constraints
@@ -1228,9 +1249,9 @@ class TestPyoptSparse(unittest.TestCase):
         self.assertFalse(failed, "Optimization failed, info = " +
                                  str(prob.driver.pyopt_solution.optInform))
 
-        assert_rel_error(self, prob['z'][0], 1.9776, 1e-3)
-        assert_rel_error(self, prob['z'][1], 0.0, 1e-3)
-        assert_rel_error(self, prob['x'], 0.0, 4e-3)
+        assert_near_equal(prob['z'][0], 1.9776, 1e-3)
+        assert_near_equal(prob['z'][1], 0.0, 1e-3)
+        assert_near_equal(prob['x'], 0.0, 4e-3)
 
         # Piggyback test: make sure we can run the driver again as a subdriver without a keyerror.
         prob.driver.run()
@@ -1270,8 +1291,8 @@ class TestPyoptSparse(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-6)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-6)
+        assert_near_equal(prob['x'], 7.16667, 1e-6)
+        assert_near_equal(prob['y'], -7.833334, 1e-6)
 
         # Normally it takes 9 iterations, but takes 13 here because of the
         # analysis failures. (note SLSQP takes 5 instead of 4)
@@ -1363,8 +1384,8 @@ class TestPyoptSparse(unittest.TestCase):
             tol = 1e-6
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, tol)
-        assert_rel_error(self, prob['y'], -7.833334, tol)
+        assert_near_equal(prob['x'], 7.16667, tol)
+        assert_near_equal(prob['y'], -7.833334, tol)
 
         # Normally it takes 9 iterations, but takes 13 here because of the
         # gradfunc failures. (note SLSQP just doesn't do well)
@@ -1534,6 +1555,11 @@ class TestPyoptSparse(unittest.TestCase):
 
     def test_show_exception_bad_opt(self):
 
+        # First, check if we have the optimizer for this test. If they do, then just skip it.
+        _, loc_opt = set_pyoptsparse_opt('NOMAD')
+        if loc_opt == 'NOMAD':
+            raise unittest.SkipTest("Skipping because user has this optimizer.")
+
         prob = om.Problem()
         model = prob.model
 
@@ -1551,15 +1577,15 @@ class TestPyoptSparse(unittest.TestCase):
 
         prob.driver = pyOptSparseDriver()
 
-        # We generally don't hae a working IPOPT install.
-        prob.driver.options['optimizer'] = 'IPOPT'
+        # We generally don't hae a working NOMAD install.
+        prob.driver.options['optimizer'] = 'NOMAD'
         prob.setup()
 
         # Test that we get exception.
         with self.assertRaises(ImportError) as raises_cm:
             prob.run_driver()
 
-        self.assertTrue("IPOPT is not available" in str(raises_cm.exception))
+        self.assertTrue("NOMAD is not available" in str(raises_cm.exception))
 
     # Travis testing core dumps on many of the machines. Probabaly a build problem with the NSGA source.
     # Limiting this to the single travis 1.14 machine for now.
@@ -1811,6 +1837,31 @@ class TestPyoptSparse(unittest.TestCase):
         code = prob.driver.pyopt_solution.optInform['value']
         self.assertEqual(code, 71)
 
+    def test_IPOPT_basic(self):
+        _, local_opt = set_pyoptsparse_opt('IPOPT')
+        if local_opt != 'IPOPT':
+            raise unittest.SkipTest("pyoptsparse is not providing IPOPT")
+
+        prob = om.Problem()
+        model = prob.model = SellarDerivativesGrouped()
+
+        prob.driver = om.pyOptSparseDriver()
+        prob.driver.options['optimizer'] = "IPOPT"
+        prob.driver.opt_settings['print_level'] = 0
+
+        model.add_design_var('z', lower=np.array([-10.0, 0.0]), upper=np.array([10.0, 10.0]))
+        model.add_design_var('x', lower=0.0, upper=10.0)
+        model.add_objective('obj')
+        model.add_constraint('con1', upper=0.0)
+        model.add_constraint('con2', upper=0.0)
+
+        prob.set_solver_print(level=0)
+
+        prob.setup(check=False, mode='rev')
+        prob.run_driver()
+
+        assert_near_equal(prob['z'][0], 1.9776, 1e-3)
+
 
 @unittest.skipIf(OPT is None or OPTIMIZER is None, "only run if pyoptsparse is installed.")
 @use_tempdirs
@@ -1847,7 +1898,7 @@ class TestPyoptSparseFeature(unittest.TestCase):
         prob.setup(check=False, mode='rev')
         prob.run_driver()
 
-        assert_rel_error(self, prob['z'][0], 1.9776, 1e-3)
+        assert_near_equal(prob['z'][0], 1.9776, 1e-3)
 
     def test_settings_print(self):
         import numpy as np
@@ -1873,7 +1924,7 @@ class TestPyoptSparseFeature(unittest.TestCase):
         prob.setup(check=False, mode='rev')
         prob.run_driver()
 
-        assert_rel_error(self, prob['z'][0], 1.9776, 1e-3)
+        assert_near_equal(prob['z'][0], 1.9776, 1e-3)
 
     def test_slsqp_atol(self):
         import numpy as np
@@ -1900,7 +1951,7 @@ class TestPyoptSparseFeature(unittest.TestCase):
         prob.setup(check=False, mode='rev')
         prob.run_driver()
 
-        assert_rel_error(self, prob['z'][0], 1.9776, 1e-3)
+        assert_near_equal(prob['z'][0], 1.9776, 1e-3)
 
     def test_slsqp_maxit(self):
         import numpy as np
@@ -1927,7 +1978,7 @@ class TestPyoptSparseFeature(unittest.TestCase):
         prob.setup(check=False, mode='rev')
         prob.run_driver()
 
-        assert_rel_error(self, prob['z'][0], 1.98337708, 1e-3)
+        assert_near_equal(prob['z'][0], 1.98337708, 1e-3)
 
 
 class TestPyoptSparseSnoptFeature(unittest.TestCase):
@@ -1963,7 +2014,7 @@ class TestPyoptSparseSnoptFeature(unittest.TestCase):
         prob.setup(check=False, mode='rev')
         prob.run_driver()
 
-        assert_rel_error(self, prob['z'][0], 1.9776, 1e-3)
+        assert_near_equal(prob['z'][0], 1.9776, 1e-3)
 
     def test_snopt_maxit(self):
         import numpy as np
@@ -1992,7 +2043,7 @@ class TestPyoptSparseSnoptFeature(unittest.TestCase):
 
         prob.run_driver()
 
-        assert_rel_error(self, prob['z'][0], 1.9780247, 2e-3)
+        assert_near_equal(prob['z'][0], 1.9780247, 2e-3)
 
     def test_snopt_fd_solution(self):
 
@@ -2026,8 +2077,8 @@ class TestPyoptSparseSnoptFeature(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-6)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-6)
+        assert_near_equal(prob['x'], 7.16667, 1e-6)
+        assert_near_equal(prob['y'], -7.833334, 1e-6)
 
     def test_snopt_fd_is_called(self):
 
@@ -2066,8 +2117,8 @@ class TestPyoptSparseSnoptFeature(unittest.TestCase):
                                  str(prob.driver.pyopt_solution.optInform))
 
         # Minimum should be at (7.166667, -7.833334)
-        assert_rel_error(self, prob['x'], 7.16667, 1e-6)
-        assert_rel_error(self, prob['y'], -7.833334, 1e-6)
+        assert_near_equal(prob['x'], 7.16667, 1e-6)
+        assert_near_equal(prob['y'], -7.833334, 1e-6)
 
     def test_sellar_analysis_error(self):
         # One discipline of Sellar will something raise analysis error. This is to test that
@@ -2184,9 +2235,9 @@ class TestPyoptSparseSnoptFeature(unittest.TestCase):
         self.assertFalse(failed, "Optimization failed, info = " +
                                  str(prob.driver.pyopt_solution.optInform))
 
-        assert_rel_error(self, prob['z'][0], 1.9776, 1e-3)
-        assert_rel_error(self, prob['z'][1], 0.0, 1e-3)
-        assert_rel_error(self, prob['x'], 0.0, 1e-3)
+        assert_near_equal(prob['z'][0], 1.9776, 1e-3)
+        assert_near_equal(prob['z'][1], 0.0, 1e-3)
+        assert_near_equal(prob['x'], 0.0, 1e-3)
 
         self.assertEqual(model.cycle.d1.failed, 2)
 
@@ -2206,5 +2257,84 @@ class TestPyoptSparseSnoptFeature(unittest.TestCase):
         prob.driver.options['user_teriminate_signal'] = signal.SIGUSR2
 
 
+class MatMultCompExact(om.ExplicitComponent):
+    def __init__(self, mat, sparse=False, **kwargs):
+        super(MatMultCompExact, self).__init__(**kwargs)
+        self.mat = mat
+        self.sparse = sparse
+
+    def setup(self):
+        self.add_input('x', val=np.ones(self.mat.shape[1]))
+        self.add_output('y', val=np.zeros(self.mat.shape[0]))
+
+        if self.sparse:
+            self.rows, self.cols = np.nonzero(self.mat)
+            self.declare_partials(of='y', wrt='x', rows=self.rows, cols=self.cols)
+        else:
+            self.declare_partials(of='y', wrt='x')
+        self.num_computes = 0
+
+    def compute(self, inputs, outputs):
+        outputs['y'] = self.mat.dot(inputs['x'])
+        self.num_computes += 1
+
+    def compute_partials(self, inputs, partials):
+        """
+        Compute the sparse partials.
+
+        Parameters
+        ----------
+        inputs : Vector
+            unscaled, dimensional input variables read via inputs[key]
+        partials : Jacobian
+            sub-jac components written to partials[output_name, input_name]
+        """
+        if self.sparse:
+            partials['y', 'x'] = self.mat[self.rows, self.cols]
+        else:
+            partials['y', 'x'] = self.mat
+
+
+class MyGroup(om.Group):
+    def __init__(self, size=5):
+        super(MyGroup, self).__init__()
+        self.size = size
+
+    def setup(self):
+        size = self.size
+        self.add_subsystem('indeps', om.IndepVarComp('x', np.ones(size)))
+        A = np.ones((size, size))  # force coloring to fail
+        self.add_subsystem('comp1', MatMultCompExact(A))
+        self.add_subsystem('comp2', om.ExecComp('y=x-1.0', x=np.zeros(size), y=np.zeros(size), has_diag_partials=True))
+        self.connect('indeps.x', 'comp1.x')
+        self.connect('comp1.y', 'comp2.x')
+        self.add_design_var('indeps.x')
+        self.add_objective('comp2.y', index=0)
+        self.add_constraint('comp1.y', indices=list(range(1, size)), lower=5., upper=10.)
+
+
+@unittest.skipIf(OPT is None or OPTIMIZER is None, "only run if pyoptsparse is installed.")
+@use_tempdirs
+class TestResizingTestCase(unittest.TestCase):
+    def test_resize(self):
+        # this test just verifies that pyoptsparsedriver doesn't raise an exception due
+        # to mismatched sizes in the sparsity definition, so this test passes as long as
+        # an exception isn't raised.
+        p = om.Problem()
+        model = p.model
+        p.driver = om.pyOptSparseDriver()
+        p.driver.declare_coloring()
+
+        G = model.add_subsystem("G", MyGroup(5))
+        p.setup()
+        p.run_driver()
+        p.compute_totals()
+
+        G.size = 10
+        p.setup()
+        p.run_driver()
+        p.compute_totals()
+
+
 if __name__ == "__main__":
     unittest.main()
