@@ -1,8 +1,6 @@
 """A module containing various configuration checks for an OpenMDAO Problem."""
-from __future__ import print_function
 
 from collections import defaultdict
-from six import iteritems
 from distutils.version import LooseVersion
 
 import numpy as np
@@ -161,7 +159,7 @@ def _get_used_before_calc_subs(group, input_srcs):
     glen = len(group.pathname.split('.')) if group.pathname else 0
 
     ubcs = defaultdict(set)
-    for tgt_abs, src_abs in iteritems(input_srcs):
+    for tgt_abs, src_abs in input_srcs.items():
         if src_abs is not None:
             iparts = tgt_abs.split('.')
             oparts = src_abs.split('.')
@@ -190,17 +188,17 @@ def _check_dup_comp_inputs(problem, logger):
 
     input_srcs = problem.model._conn_global_abs_in2out
     src2inps = defaultdict(list)
-    for inp, src in iteritems(input_srcs):
+    for inp, src in input_srcs.items():
         src2inps[src].append(inp)
 
     msgs = []
-    for src, inps in iteritems(src2inps):
+    for src, inps in src2inps.items():
         comps = defaultdict(list)
         for inp in inps:
             comp, vname = inp.rsplit('.', 1)
             comps[comp].append(vname)
 
-        dups = sorted([(c, v) for c, v in iteritems(comps) if len(v) > 1], key=lambda x: x[0])
+        dups = sorted([(c, v) for c, v in comps.items() if len(v) > 1], key=lambda x: x[0])
         if dups:
             for comp, vnames in dups:
                 msgs.append("   %s has inputs %s connected to %s\n" % (comp, sorted(vnames), src))
@@ -314,7 +312,7 @@ def _check_hanging_inputs(problem, logger):
     unconns = []
     nwid = uwid = 0
 
-    for prom, abslist in iteritems(prom_ins):
+    for prom, abslist in prom_ins.items():
         unconn = [a for a in abslist if a not in input_srcs or len(input_srcs[a]) == 0]
         if unconn:
             w = max([len(u) for u in unconn])
@@ -530,7 +528,7 @@ def _get_promoted_connected_ins(g):
 
     for subsys in g._subgroups_myproc:
         sub_prom_conn_ins = _get_promoted_connected_ins(subsys)
-        for n, tup in iteritems(sub_prom_conn_ins):
+        for n, tup in sub_prom_conn_ins.items():
             proms, mans = tup
             mytup = prom_conn_ins[n]
             mytup[0].extend(proms)
@@ -538,7 +536,7 @@ def _get_promoted_connected_ins(g):
 
         sub_abs2prom_in = subsys._var_abs2prom['input']
 
-        for inp, sub_prom_inp in iteritems(sub_abs2prom_in):
+        for inp, sub_prom_inp in sub_abs2prom_in.items():
             if abs2prom_in[inp] == sub_prom_inp:  # inp is promoted up from sub
                 if inp in sub_prom_conn_ins and len(sub_prom_conn_ins[inp][1]) > 0:
                     prom_conn_ins[inp][0].append(subsys.pathname)
@@ -559,7 +557,7 @@ def _check_explicitly_connected_promoted_inputs(problem, logger):
     """
     prom_conn_ins = _get_promoted_connected_ins(problem.model)
 
-    for inp, lst in iteritems(prom_conn_ins):
+    for inp, lst in prom_conn_ins.items():
         proms, mans = lst
         if proms:
             # there can only be one manual connection (else an exception would've been raised)
