@@ -3,7 +3,6 @@ A Case class.
 """
 
 import sys
-import re
 import itertools
 
 from collections import OrderedDict
@@ -14,7 +13,8 @@ from openmdao.recorders.sqlite_recorder import blob_to_array
 from openmdao.utils.record_util import deserialize, get_source_system
 from openmdao.utils.variable_table import write_var_table
 from openmdao.utils.general_utils import make_set, match_includes_excludes
-from openmdao.utils.units import get_conversion
+from openmdao.utils.units import unit_conversion
+from openmdao.recorders.sqlite_recorder import format_version as current_version
 
 _DEFAULT_OUT_STREAM = object()
 _AMBIGOUS_PROM_NAME = object()
@@ -46,7 +46,7 @@ class Case(object):
         Map of inputs to values recorded, None if not recorded.
     residuals : PromAbsDict or None
         Map of outputs to residuals recorded, None if not recorded.
-    jacobian : PromAbsDict or None
+    derivatives : PromAbsDict or None
         Map of (output, input) to derivatives recorded, None if not recorded.
     parent : str
         The full unique identifier for the parent this iteration.
@@ -125,7 +125,7 @@ class Case(object):
         self.inputs = None
         self.outputs = None
         self.residuals = None
-        self.jacobian = None
+        self.derivatives = None
 
         if 'inputs' in data.keys():
             if data_format >= 3:
@@ -171,7 +171,7 @@ class Case(object):
             else:
                 jacobian = data['jacobian']
             if jacobian is not None:
-                self.jacobian = PromAbsDict(jacobian, prom2abs['output'], abs2prom['output'])
+                self.derivatives = PromAbsDict(jacobian, prom2abs['output'], abs2prom['output'])
 
         # save var name & meta dict references for use by self._get_variables_of_type()
         self._prom2abs = prom2abs
@@ -250,7 +250,7 @@ class Case(object):
                 raise TypeError(msg.format(name, units))
 
             try:
-                scale, offset = get_conversion(base_units, units)
+                scale, offset = unit_conversion(base_units, units)
             except TypeError:
                 msg = "Can't express variable '{}' with units of '{}' in units of '{}'."
                 raise TypeError(msg.format(name, base_units, units))
@@ -694,10 +694,10 @@ class Case(object):
                     if use_indices and meta['indices'] is not None:
                         val = val[meta['indices']]
                     if scaled:
-                        if meta['adder'] is not None:
-                            val += meta['adder']
-                        if meta['scaler'] is not None:
-                            val *= meta['scaler']
+                        if meta['total_adder'] is not None:
+                            val += meta['total_adder']
+                        if meta['total_scaler'] is not None:
+                            val *= meta['total_scaler']
                     ret_vars[name] = val
 
         return PromAbsDict(ret_vars, self._prom2abs['output'], self._abs2prom['output'])
@@ -717,9 +717,11 @@ class PromAbsDict(dict):
         Dictionary mapping promoted names to absolute names.
     _abs2prom : dict
         Dictionary mapping absolute names to promoted names.
+    _DERIV_KEY_SEP : str
+        Separator character for derivative keys.
     """
 
-    def __init__(self, values, prom2abs, abs2prom):
+    def __init__(self, values, prom2abs, abs2prom, data_format=current_version):
         """
         Initialize.
 
@@ -731,12 +733,19 @@ class PromAbsDict(dict):
             Dictionary mapping promoted names to absolute names.
         abs2prom : dict
             Dictionary mapping absolute names to promoted names.
+        data_format : int
+            A version number specifying the OpenMDAO SQL case database version.
         """
         super(PromAbsDict, self).__init__()
 
         self._prom2abs = prom2abs
         self._abs2prom = abs2prom
 
+        if data_format <= 8:
+            DERIV_KEY_SEP = self._DERIV_KEY_SEP = ','
+        else:
+            DERIV_KEY_SEP = self._DERIV_KEY_SEP = '!'
+
         if isinstance(values, dict):
             # dict of values, keyed on either absolute or promoted names
             self._values = {}
@@ -751,8 +760,8 @@ class PromAbsDict(dict):
                     for abs_key in prom2abs[key]:
                         self._values[abs_key] = values[key]
                     super(PromAbsDict, self).__setitem__(key, values[key])
-                elif isinstance(key, tuple) or ',' in key:
-                    # derivative keys can be either (of, wrt) or 'of,wrt'
+                elif isinstance(key, tuple) or DERIV_KEY_SEP in key:
+                    # derivative keys can be either (of, wrt) or 'of!wrt'
                     abs_keys, prom_key = self._deriv_keys(key)
                     for abs_key in abs_keys:
                         self._values[abs_key] = values[key]
@@ -772,8 +781,8 @@ class PromAbsDict(dict):
                         super(PromAbsDict, self).__setitem__(prom_key, _AMBIGOUS_PROM_NAME)
                     else:
                         super(PromAbsDict, self).__setitem__(prom_key, self._values[key])
-                elif ',' in key:
-                    # derivative keys will be a string in the form of 'of,wrt'
+                elif DERIV_KEY_SEP in key:
+                    # derivative keys will be a string in the form of 'of!wrt'
                     abs_keys, prom_key = self._deriv_keys(key)
                     super(PromAbsDict, self).__setitem__(prom_key, self._values[key])
 
@@ -795,7 +804,7 @@ class PromAbsDict(dict):
         Parameters
         ----------
         key : tuple or string
-            derivative key as either (of, wrt) or 'of,wrt'.
+            derivative key as either (of, wrt) or 'of!wrt'.
 
         Returns
         -------
@@ -807,16 +816,18 @@ class PromAbsDict(dict):
         prom2abs = self._prom2abs
         abs2prom = self._abs2prom
 
+        DERIV_KEY_SEP = self._DERIV_KEY_SEP
+
         # derivative could be tuple or string, using absolute or promoted names
         if isinstance(key, tuple):
             of, wrt = key
         else:
-            of, wrt = re.sub('[( )]', '', key).split(',')
+            of, wrt = key.split(DERIV_KEY_SEP)
 
         # if promoted, will map to all connected absolute names
         abs_of = [of] if of in abs2prom else prom2abs[of]
         abs_wrt = [wrt] if wrt in abs2prom else prom2abs[wrt]
-        abs_keys = ['%s,%s' % (o, w) for o, w in itertools.product(abs_of, abs_wrt)]
+        abs_keys = ['%s%s%s' % (o, DERIV_KEY_SEP, w) for o, w in itertools.product(abs_of, abs_wrt)]
 
         prom_of = of if of in prom2abs else abs2prom[of]
         prom_wrt = wrt if wrt in prom2abs else abs2prom[wrt]
@@ -853,8 +864,8 @@ class PromAbsDict(dict):
             else:
                 return val
 
-        elif isinstance(key, tuple) or ',' in key:
-            # derivative keys can be either (of, wrt) or 'of,wrt'
+        elif isinstance(key, tuple) or self._DERIV_KEY_SEP in key:
+            # derivative keys can be either (of, wrt) or 'of!wrt'
             abs_keys, prom_key = self._deriv_keys(key)
             return super(PromAbsDict, self).__getitem__(prom_key)
 
@@ -871,8 +882,8 @@ class PromAbsDict(dict):
         value : any
             value for variable
         """
-        if isinstance(key, tuple) or ',' in key:
-            # derivative keys can be either (of, wrt) or 'of,wrt'
+        if isinstance(key, tuple) or self._DERIV_KEY_SEP in key:
+            # derivative keys can be either (of, wrt) or 'of!wrt'
             abs_keys, prom_key = self._deriv_keys(key)
 
             for abs_key in abs_keys:
@@ -902,10 +913,12 @@ class PromAbsDict(dict):
         str
             absolute names for variables contained in this dictionary.
         """
+        DERIV_KEY_SEP = self._DERIV_KEY_SEP
+
         for key in self._keys:
-            if ',' in key:
+            if DERIV_KEY_SEP in key:
                 # return derivative keys as tuples instead of strings
-                of, wrt = re.sub('[( )]', '', key).split(',')
+                of, wrt = key.split(DERIV_KEY_SEP)
                 yield (of, wrt)
             else:
                 yield key
