@@ -1,9 +1,4 @@
 """Define the LinearBlockGS class."""
-from __future__ import print_function
-
-from six import iteritems
-from six.moves import range
-
 
 from openmdao.solvers.solver import BlockLinearSolver
 
