@@ -10,7 +10,7 @@ from openmdao.test_suite.components.sellar import SellarImplicitDis1, SellarImpl
     SellarDis1withDerivatives, SellarDis2withDerivatives
 from openmdao.test_suite.components.expl_comp_simple import TestExplCompSimpleDense
 from openmdao.test_suite.components.sellar import SellarDerivatives
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 
 
 class SimpleImp(om.ImplicitComponent):
@@ -137,7 +137,7 @@ class TestBGSSolver(LinearSolverTests.LinearSolverTestCase):
 
         derivs = prob.compute_totals(of=['sub.z'], wrt=['sub.z'])
 
-        assert_rel_error(self, derivs[('sub.z', 'sub.z')], [[0., 1.]])
+        assert_near_equal(derivs[('sub.z', 'sub.z')], [[0., 1.]])
 
 
 class TestBGSSolverFeature(unittest.TestCase):
@@ -174,8 +174,8 @@ class TestBGSSolverFeature(unittest.TestCase):
         of = ['obj']
 
         J = prob.compute_totals(of=of, wrt=wrt, return_format='flat_dict')
-        assert_rel_error(self, J['obj', 'z'][0][0], 9.61001056, .00001)
-        assert_rel_error(self, J['obj', 'z'][0][1], 1.78448534, .00001)
+        assert_near_equal(J['obj', 'z'][0][0], 9.61001056, .00001)
+        assert_near_equal(J['obj', 'z'][0][1], 1.78448534, .00001)
 
     def test_feature_maxiter(self):
         import numpy as np
@@ -211,8 +211,8 @@ class TestBGSSolverFeature(unittest.TestCase):
         of = ['obj']
 
         J = prob.compute_totals(of=of, wrt=wrt, return_format='flat_dict')
-        assert_rel_error(self, J['obj', 'z'][0][0], 9.60230118004, .00001)
-        assert_rel_error(self, J['obj', 'z'][0][1], 1.78022500547, .00001)
+        assert_near_equal(J['obj', 'z'][0][0], 9.60230118004, .00001)
+        assert_near_equal(J['obj', 'z'][0][1], 1.78022500547, .00001)
 
     def test_feature_atol(self):
         import numpy as np
@@ -248,8 +248,8 @@ class TestBGSSolverFeature(unittest.TestCase):
         of = ['obj']
 
         J = prob.compute_totals(of=of, wrt=wrt, return_format='flat_dict')
-        assert_rel_error(self, J['obj', 'z'][0][0], 9.61016296175, .00001)
-        assert_rel_error(self, J['obj', 'z'][0][1], 1.78456955704, .00001)
+        assert_near_equal(J['obj', 'z'][0][0], 9.61016296175, .00001)
+        assert_near_equal(J['obj', 'z'][0][1], 1.78456955704, .00001)
 
     def test_feature_rtol(self):
         import numpy as np
@@ -285,8 +285,8 @@ class TestBGSSolverFeature(unittest.TestCase):
         of = ['obj']
 
         J = prob.compute_totals(of=of, wrt=wrt, return_format='flat_dict')
-        assert_rel_error(self, J['obj', 'z'][0][0], 9.61016296175, .00001)
-        assert_rel_error(self, J['obj', 'z'][0][1], 1.78456955704, .00001)
+        assert_near_equal(J['obj', 'z'][0][0], 9.61016296175, .00001)
+        assert_near_equal(J['obj', 'z'][0][1], 1.78456955704, .00001)
 
 
 if __name__ == "__main__":
