@@ -3,7 +3,6 @@
 import numpy as np
 
 from openmdao.solvers.solver import NonlinearSolver
-from openmdao.utils.general_utils import warn_deprecation
 from openmdao.utils.mpi import MPI
 
 
@@ -52,16 +51,6 @@ class NonlinearBlockGS(NonlinearSolver):
 
         rank = MPI.COMM_WORLD.rank if MPI is not None else 0
 
-        if self.options._dict['reraise_child_analysiserror']['value']:
-            pathname = self._system().pathname
-            if pathname:
-                pathname += ': '
-            msg = ("Deprecation warning: In V 3.x, reraise_child_analysiserror will default to "
-                   "False.")
-
-            if rank == 0:
-                warn_deprecation(pathname + msg)
-
         if len(system._subsystems_allprocs) != len(system._subsystems_myproc):
             raise RuntimeError('{}: Nonlinear Gauss-Seidel cannot be used on a '
                                'parallel group.'.format(self.msginfo))
@@ -84,7 +73,7 @@ class NonlinearBlockGS(NonlinearSolver):
         self.options.declare('use_apply_nonlinear', types=bool, default=False,
                              desc="Set to True to always call apply_nonlinear on the solver's "
                              "system after solve_nonlinear has been called.")
-        self.options.declare('reraise_child_analysiserror', types=bool, default=True,
+        self.options.declare('reraise_child_analysiserror', types=bool, default=False,
                              desc='When the option is true, a solver will reraise any '
                              'AnalysisError that arises during subsolve; when false, it will '
                              'continue solving.')
