@@ -11,6 +11,7 @@ from openmdao.utils.array_utils import evenly_distrib_idxs
 
 
 class DistribComp(om.ExplicitComponent):
+    """Simple Distributed Component."""
 
     def initialize(self):
         self.options['distributed'] = True
@@ -24,15 +25,17 @@ class DistribComp(om.ExplicitComponent):
 
         size = self.options['size']
 
-        # results in 8 entries for proc 0 and 7 entries for proc 1 when using 2 processes.
+        # if comm.size is 2 and size is 15, this results in
+        # 8 entries for proc 0 and 7 entries for proc 1
         sizes, offsets = evenly_distrib_idxs(comm.size, size)
+        mysize = sizes[rank]
         start = offsets[rank]
-        end = start + sizes[rank]
+        end = start + mysize
 
-        self.add_input('invec', np.ones(sizes[rank], float),
+        self.add_input('invec', np.ones(mysize, float),
                        src_indices=np.arange(start, end, dtype=int))
 
-        self.add_output('outvec', np.ones(sizes[rank], float))
+        self.add_output('outvec', np.ones(mysize, float))
 
     def compute(self, inputs, outputs):
         if self.comm.rank == 0:
@@ -42,37 +45,80 @@ class DistribComp(om.ExplicitComponent):
 
 
 class Summer(om.ExplicitComponent):
-    """Sums a distributed input."""
+    """Sums an input array."""
 
     def initialize(self):
         self.options.declare('size', types=int, default=1,
                              desc="Size of input and output vectors.")
 
+    def setup(self):
+        self.add_input('invec', np.ones(self.options['size'], float))
+
+        self.add_output('sum', 0.0, shape=1)
+
+    def compute(self, inputs, outputs):
+        outputs['sum'] = np.sum(inputs['invec'])
+
+
+class DistribCompDerivs(om.ExplicitComponent):
+    """Simple Distributed Component with Derivatives."""
+
+    def initialize(self):
+        self.options['distributed'] = True
+
+        self.options.declare('size', types=int, default=1,
+                             desc="Size of input and output vectors.")
+
     def setup(self):
         comm = self.comm
         rank = comm.rank
 
         size = self.options['size']
 
-        # this results in 8 entries for proc 0 and 7 entries for proc 1
-        # when using 2 processes.
-        sizes, offsets = evenly_distrib_idxs(comm.size, size)
-        start = offsets[rank]
-        end = start + sizes[rank]
+        # if comm.size is 2 and size is 15, this results in
+        # 8 entries for proc 0 and 7 entries for proc 1
+        sizes, _ = evenly_distrib_idxs(comm.size, size)
+        self.mysize = mysize = sizes[rank]
 
-        # NOTE: you must specify src_indices here for the input. Otherwise,
-        #       you'll connect the input to [0:local_input_size] of the
-        #       full distributed output!
-        self.add_input('invec', np.ones(sizes[rank], float),
-                       src_indices=np.arange(start, end, dtype=int))
+        # don't set src_indices on the input, just use default behavior
+        self.add_input('invec', np.ones(mysize, float))
+        self.add_output('outvec', np.ones(mysize, float))
 
-        self.add_output('out', 0.0)
+        # declare partial derivatives (diagonal of mysize)
+        self.declare_partials('outvec', 'invec', 
+                              rows=np.arange(0, mysize),
+                              cols=np.arange(0, mysize))
 
     def compute(self, inputs, outputs):
-        data = np.zeros(1)
-        data[0] = np.sum(inputs['invec'])
+        if self.comm.rank == 0:
+            outputs['outvec'] = inputs['invec'] * 2.0
+        else:
+            outputs['outvec'] = inputs['invec'] * -3.0
 
-        total = np.zeros(1)
-        self.comm.Allreduce(data, total, op=MPI.SUM)
+    def compute_partials(self, inputs, J):
+        # get mysize from the input vector for this process
+        mysize = inputs['invec'].size
 
-        outputs['out'] = total[0]
+        if self.comm.rank == 0:
+            J['outvec', 'invec'] = np.ones((mysize,)) * 2.0
+        else:
+            J['outvec', 'invec'] = np.ones((mysize,)) * -3.0
+
+
+class SummerDerivs(om.ExplicitComponent):
+    """Sums an input array."""
+
+    def initialize(self):
+        self.options.declare('size', types=int, default=1,
+                             desc="Size of input and output vectors.")
+
+    def setup(self):
+        self.add_input('invec', np.ones(self.options['size'], float))
+
+        self.add_output('sum', 0.0, shape=1)
+
+        # the derivative is constant
+        self.declare_partials('sum', 'invec', val=1.)
+
+    def compute(self, inputs, outputs):
+        outputs['sum'] = np.sum(inputs['invec'])
