@@ -4,7 +4,7 @@ import unittest
 import scipy
 
 import openmdao.api as om
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 
 
 # duplicate definition here so it can be included in docs by itself
@@ -206,12 +206,12 @@ class TestBetzLimit(unittest.TestCase):
         prob.model.list_outputs(values = False, hierarchical=False)
 
         # minimum value
-        assert_rel_error(self, prob['a_disk.Cp'], 16./27., 1e-4)
-        assert_rel_error(self, prob['a'], 0.33333, 1e-4)
+        assert_near_equal(prob['a_disk.Cp'], 16./27., 1e-4)
+        assert_near_equal(prob['a'], 0.33333, 1e-4)
 
         # There is a bug in scipy version < 1.0 that causes this value to be wrong.
         if LooseVersion(scipy.__version__) >= LooseVersion("1.0"):
-            assert_rel_error(self, prob['Area'], 1.0, 1e-4)
+            assert_near_equal(prob['Area'], 1.0, 1e-4)
 
     def test_betz_with_var_tags(self):
         import openmdao.api as om
