@@ -1,6 +1,6 @@
 import unittest
 
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 
 
 class TestParaboloidTLDR(unittest.TestCase):
@@ -31,11 +31,11 @@ class TestParaboloidTLDR(unittest.TestCase):
         prob.run_driver()
 
         # minimum value
-        assert_rel_error(self, prob['paraboloid.f'], -27.33333, 1e-6)
+        assert_near_equal(prob['paraboloid.f'], -27.33333, 1e-6)
 
         # location of the minimum
-        assert_rel_error(self, prob['indeps.x'], 6.6667, 1e-4)
-        assert_rel_error(self, prob['indeps.y'], -7.33333, 1e-4)
+        assert_near_equal(prob['indeps.x'], 6.6667, 1e-4)
+        assert_near_equal(prob['indeps.y'], -7.33333, 1e-4)
 
 if __name__ == "__main__":
 
