@@ -1,6 +1,4 @@
 """Some miscellaneous utility functions."""
-from __future__ import division
-
 from contextlib import contextmanager
 import os
 import re
@@ -9,8 +7,7 @@ import math
 import warnings
 import unittest
 from fnmatch import fnmatchcase
-from six import string_types, PY2, reraise
-from six.moves import range, cStringIO as StringIO
+from io import StringIO
 
 # note: this is a Python 3.3 change, clean this up for OpenMDAO 3.x
 try:
@@ -397,7 +394,7 @@ def format_as_float_or_array(name, values, val_if_none=0.0, flatten=False):
     if isinstance(values, np.ndarray):
         if flatten:
             values = values.flatten()
-    elif not isinstance(values, string_types) \
+    elif not isinstance(values, str) \
             and isinstance(values, Iterable):
         values = np.asarray(values, dtype=float)
         if flatten:
@@ -536,10 +533,9 @@ def run_model(prob, ignore_exception=False):
     sys.stdout = strout
     try:
         prob.run_model()
-    except Exception:
+    except Exception as err:
         if not ignore_exception:
-            exc = sys.exc_info()
-            reraise(*exc)
+            raise err
     finally:
         sys.stdout = stdout
 
@@ -690,10 +686,7 @@ def json_load_byteified(file_handle):
     data item or structure
         data item or structure with unicode converted to bytes
     """
-    if PY2:
-        return _byteify(json.load(file_handle, object_hook=_byteify), ignore_dicts=True)
-    else:
-        return json.load(file_handle)
+    return json.load(file_handle)
 
 
 def json_loads_byteified(json_str):
@@ -712,10 +705,7 @@ def json_loads_byteified(json_str):
     data item or structure
         data item or structure with unicode converted to bytes
     """
-    if PY2:
-        return _byteify(json.loads(json_str, object_hook=_byteify), ignore_dicts=True)
-    else:
-        return json.loads(json_str)
+    return json.loads(json_str)
 
 
 def remove_whitespace(s, right=False, left=False):
@@ -750,11 +740,7 @@ def remove_whitespace(s, right=False, left=False):
 
 
 _badtab = r'`~@#$%^&*()[]{}-+=|\/?<>,.:;'
-if PY2:
-    import string
-    _transtab = string.maketrans(_badtab, '_' * len(_badtab))
-else:
-    _transtab = str.maketrans(_badtab, '_' * len(_badtab))
+_transtab = str.maketrans(_badtab, '_' * len(_badtab))
 
 
 def str2valid_python_name(s):
