@@ -5,15 +5,7 @@ import json
 import os
 from collections import OrderedDict
 from itertools import chain
-
 import networkx as nx
-from six import iteritems, itervalues
-
-try:
-    import h5py
-except ImportError:
-    # Necessary for the file to parse
-    h5py = None
 
 from openmdao.components.exec_comp import ExecComp
 from openmdao.components.meta_model_structured_comp import MetaModelStructuredComp
@@ -29,7 +21,7 @@ from openmdao.drivers.doe_driver import DOEDriver
 from openmdao.recorders.case_reader import CaseReader
 from openmdao.solvers.nonlinear.newton import NewtonSolver
 from openmdao.utils.class_util import overrides_method
-from openmdao.utils.general_utils import warn_deprecation, simple_warning, make_serializable
+from openmdao.utils.general_utils import simple_warning, make_serializable
 from openmdao.utils.record_util import check_valid_sqlite3_db
 from openmdao.utils.mpi import MPI
 from openmdao.visualization.html_utils import read_files, write_script, DiagramWriter
@@ -50,6 +42,7 @@ def _get_var_dict(system, typ, name):
         name = system._var_abs2prom[typ][name]
 
     var_dict = OrderedDict()
+
     var_dict['name'] = name
     if typ == 'input':
         var_dict['type'] = 'param'
@@ -59,7 +52,6 @@ def _get_var_dict(system, typ, name):
         var_dict['implicit'] = isimplicit
 
     var_dict['dtype'] = type(meta['value']).__name__
-
     return var_dict
 
 
@@ -175,10 +167,9 @@ def _get_declare_partials(system):
     declare_partials_list = []
 
     def recurse_get_partials(system, dpl):
-
         if isinstance(system, Component):
             subjacs = system._subjacs_info
-            for abs_key, meta in iteritems(subjacs):
+            for abs_key, meta in subjacs.items():
                 dpl.append("{} > {}".format(abs_key[0], abs_key[1]))
         elif isinstance(system, Group):
             for s in system._subsystems_myproc:
@@ -232,7 +223,13 @@ def _get_viewer_data(data_source):
             return {}
 
     elif isinstance(data_source, str):
-        return CaseReader(data_source, pre_load=False).problem_metadata
+        data_dict = CaseReader(data_source, pre_load=False).problem_metadata
+
+        # Delete the variables key since it's not used in N2
+        if 'variables' in data_dict:
+            del data_dict['variables']
+
+        return data_dict
 
     else:
         raise TypeError(
@@ -283,12 +280,12 @@ def _get_viewer_data(data_source):
                     exe_low <= orders[t] <= exe_high and
                     not (s == src and t == tgt) and t in sys_pathnames_dict
                 ]
-                for vsrc, vtgtlist in iteritems(G.get_edge_data(src, tgt)['conns']):
+                for vsrc, vtgtlist in G.get_edge_data(src, tgt)['conns'].items():
                     for vtgt in vtgtlist:
                         connections_list.append({'src': vsrc, 'tgt': vtgt,
                                                  'cycle_arrows': edges_list})
             else:  # edge is out of the SCC
-                for vsrc, vtgtlist in iteritems(G.get_edge_data(src, tgt)['conns']):
+                for vsrc, vtgtlist in G.get_edge_data(src, tgt)['conns'].items():
                     for vtgt in vtgtlist:
                         connections_list.append({'src': vsrc, 'tgt': vtgt})
 
@@ -306,36 +303,6 @@ def _get_viewer_data(data_source):
     return data_dict
 
 
-def view_tree(*args, **kwargs):
-    """
-    view_tree was renamed to n2, but left here for backwards compatibility.
-
-    Parameters
-    ----------
-    *args : dict
-        Positional args.
-    **kwargs : dict
-        Keyword args.
-    """
-    warn_deprecation("view_tree is deprecated. Please switch to n2.")
-    n2(*args, **kwargs)
-
-
-def view_model(*args, **kwargs):
-    """
-    view_model was renamed to n2, but left here for backwards compatibility.
-
-    Parameters
-    ----------
-    *args : dict
-        Positional args.
-    **kwargs : dict
-        Keyword args.
-    """
-    warn_deprecation("view_model is deprecated. Please switch to n2.")
-    n2(*args, **kwargs)
-
-
 def n2(data_source, outfile='n2.html', show_browser=True, embeddable=False,
        title=None, use_declare_partial_info=False):
     """
@@ -387,11 +354,12 @@ def n2(data_source, outfile='n2.html', show_browser=True, embeddable=False,
     libs_dir = os.path.join(vis_dir, "libs")
     src_dir = os.path.join(vis_dir, "src")
     style_dir = os.path.join(vis_dir, "style")
+    assets_dir = os.path.join(vis_dir, "assets")
 
     # grab the libraries, src and style
     lib_dct = {'d3': 'd3.v5.min', 'awesomplete': 'awesomplete',
                'vk_beautify': 'vkBeautify'}
-    libs = read_files(itervalues(lib_dct), libs_dir, 'js')
+    libs = read_files(lib_dct.values(), libs_dir, 'js')
     src_names = \
         'modal', \
         'utils', \
@@ -405,16 +373,30 @@ def n2(data_source, outfile='n2.html', show_browser=True, embeddable=False,
         'N2Matrix', \
         'N2Arrow', \
         'N2Search', \
+        'N2Toolbar', \
         'N2Diagram', \
         'N2UserInterface', \
         'defaults', \
         'ptN2'
-    srcs = read_files(src_names, src_dir, 'js')
-    styles = read_files(('awesomplete', 'partition_tree'), style_dir, 'css')
 
-    with open(os.path.join(style_dir, "fontello.woff"), "rb") as f:
+    srcs = read_files(src_names, src_dir, 'js')
+
+    style_names = \
+        'partition_tree', \
+        'icon', \
+        'toolbar', \
+        'nodedata', \
+        'legend', \
+        'awesomplete'
+
+    styles = read_files((style_names), style_dir, 'css')
+
+    with open(os.path.join(style_dir, "icomoon.woff"), "rb") as f:
         encoded_font = str(base64.b64encode(f.read()).decode("ascii"))
 
+    with open(os.path.join(style_dir, "logo_png.b64"), "r") as f:
+        logo_png = str(f.read())
+
     if title:
         title = "OpenMDAO Model Hierarchy and N2 diagram: %s" % title
     else:
@@ -424,71 +406,30 @@ def n2(data_source, outfile='n2.html', show_browser=True, embeddable=False,
                       title=title,
                       styles=styles, embeddable=embeddable)
 
+    if (embeddable):
+        h.insert("non-embedded-n2", "embedded-n2")
+
     # put all style and JS into index
     h.insert('{{fontello}}', encoded_font)
 
-    for k, v in iteritems(lib_dct):
+    h.insert('{{logo_png}}', logo_png)
+
+    for k, v in lib_dct.items():
         h.insert('{{{}_lib}}'.format(k), write_script(libs[v], indent=_IND))
 
-    for name, code in iteritems(srcs):
+    for name, code in srcs.items():
         h.insert('{{{}_lib}}'.format(name.lower()),
                  write_script(code, indent=_IND))
 
     h.insert('{{model_data}}', write_script(model_data, indent=_IND))
 
-    # Toolbar
-    toolbar = h.toolbar
-    group1 = toolbar.add_button_group()
-    group1.add_button("Return To Root", uid="returnToRootButtonId", disabled="disabled",
-                      content="icon-home")
-    group1.add_button("Back", uid="backButtonId",
-                      disabled="disabled", content="icon-left-big")
-    group1.add_button("Forward", uid="forwardButtonId", disabled="disabled",
-                      content="icon-right-big")
-    group1.add_button("Up One Level", uid="upOneLevelButtonId", disabled="disabled",
-                      content="icon-up-big")
-
-    group2 = toolbar.add_button_group()
-    group2.add_button("Uncollapse In View Only", uid="uncollapseInViewButtonId",
-                      content="icon-resize-full")
-    group2.add_button("Uncollapse All", uid="uncollapseAllButtonId",
-                      content="icon-resize-full bigger-font")
-    group2.add_button("Collapse Outputs In View Only", uid="collapseInViewButtonId",
-                      content="icon-resize-small")
-    group2.add_button("Collapse All Outputs", uid="collapseAllButtonId",
-                      content="icon-resize-small bigger-font")
-    group2.add_dropdown("Collapse Depth", button_content="icon-sort-number-up",
-                        uid="idCollapseDepthDiv")
-
-    group3 = toolbar.add_button_group()
-    group3.add_button("Clear Arrows and Connections", uid="clearArrowsAndConnectsButtonId",
-                      content="icon-eraser")
-    group3.add_button(
-        "Show Path", uid="showCurrentPathButtonId", content="icon-terminal")
-    group3.add_button("Show Legend", uid="showLegendButtonId",
-                      content="icon-map-signs")
-    group3.add_button("Toggle Solver Names",
-                      uid="toggleSolverNamesButtonId", content="icon-minus")
-    group3.add_dropdown("Font Size", id_naming="idFontSize", options=_FONT_SIZES,
-                        option_formatter=lambda x: '{}px'.format(x),
-                        button_content="icon-text-height")
-    group3.add_dropdown("Vertically Resize", id_naming="idVerticalResize",
-                        options=_MODEL_HEIGHTS, option_formatter=lambda x: '{}px'.format(
-                            x),
-                        button_content="icon-resize-vertical", header="Model Height")
-
-    group4 = toolbar.add_button_group()
-    group4.add_button("Save SVG", uid="saveSvgButtonId", content="icon-floppy")
-
-    group5 = toolbar.add_button_group()
-    group5.add_button("Help", uid="helpButtonId", content="icon-help")
-
     # Help
     help_txt = ('Left clicking on a node in the partition tree will navigate to that node. '
-                'Right clicking on a node in the model hierarchy will collapse/uncollapse it. '
-                'A click on any element in the N^2 diagram will allow those arrows to persist.')
-
-    h.add_help(help_txt, footer="OpenMDAO Model Hierarchy and N^2 diagram")
+                'Right clicking on a node in the model hierarchy will collapse/expand it. '
+                'A click on any element in the N2 diagram will allow those arrows to persist.')
+    help_diagram_svg_filepath = os.path.join(assets_dir, "toolbar_help.svg")
+    h.add_help(help_txt, help_diagram_svg_filepath,
+               footer="OpenMDAO Model Hierarchy and N2 diagram")
 
     # Write output file
     h.write(outfile)
