@@ -26,6 +26,7 @@
  */
 class N2Diagram {
     constructor(modelJSON) {
+        this.modelData = modelJSON;
         this.model = new ModelData(modelJSON);
         this.zoomedElement = this.zoomedElementPrev = this.model.root;
         this.showPath = false;
@@ -33,6 +34,9 @@ class N2Diagram {
         // Assign this way because defaultDims is read-only.
         this.dims = JSON.parse(JSON.stringify(defaultDims));
 
+        // Keep track of arrows to show and hide them
+        this.arrowCache = [];
+
         // Find the divs for D3 content in the existing document, and add a style section.
         let parentDiv = document.getElementById("ptN2ContentDivId");
         this.dom = {
@@ -42,7 +46,8 @@ class N2Diagram {
             'svg': d3.select("#svgId"),
             'svgStyle': document.createElement("style"),
             'toolTip': d3.select(".tool-tip"),
-            'arrowMarker': d3.select("#arrow")
+            'arrowMarker': d3.select("#arrow"),
+            'nodeInfo': d3.select('#node-data')
         };
 
         // Append the new style section.
@@ -61,13 +66,13 @@ class N2Diagram {
 
         this.ui = new N2UserInterface(this);
 
+        this.toolbar = new N2Toolbar(this.ui);
+
         this._setupSvgElements();
 
         this.matrix = new N2Matrix(this.model, this.layout, this.dom.n2Groups,
             true, this.ui.findRootOfChangeFunction);
 
-        // this.matrixMax = this.matrix;
-
         // TODO: Move to N2Layout
         this.scales = {
             'unit': 'px',
@@ -96,20 +101,32 @@ class N2Diagram {
 
         this.transitCoords = {
             'unit': 'px',
-            'model': { 'x': 0, 'y': 0 },
-            'solver': { 'x': 0, 'y': 0 }
+            'model': {
+                'x': 0,
+                'y': 0
+            },
+            'solver': {
+                'x': 0,
+                'y': 0
+            }
         };
 
         this.prevTransitCoords = {
             'unit': 'px',
-            'model': { 'x': 0, 'y': 0 },
-            'solver': { 'x': 0, 'y': 0 }
+            'model': {
+                'x': 0,
+                'y': 0
+            },
+            'solver': {
+                'x': 0,
+                'y': 0
+            }
         };
     }
 
     /**
-    * Switch back and forth between showing the linear or non-linear solver names. 
-    */
+     * Switch back and forth between showing the linear or non-linear solver names. 
+     */
     toggleSolverNameType() {
         this.showLinearSolverNames = !this.showLinearSolverNames;
     }
@@ -133,7 +150,9 @@ class N2Diagram {
         svgData = '<?xml version="1.0" standalone="no"?>\r\n' + svgData;
 
         svgData = vkbeautify.xml(svgData);
-        let svgBlob = new Blob([svgData], { type: "image/svg+xml;charset=utf-8" });
+        let svgBlob = new Blob([svgData], {
+            type: "image/svg+xml;charset=utf-8"
+        });
         let svgUrl = URL.createObjectURL(svgBlob);
         let downloadLink = document.createElement("a");
         downloadLink.href = svgUrl;
@@ -186,7 +205,8 @@ class N2Diagram {
 
         this.dom.n2Groups = {};
         for (let gName of ['elements', 'gridlines', 'componentBoxes',
-            'dots', 'highlights', 'arrows']) {
+            'dots', 'highlights', 'arrows'
+        ]) {
             this.dom.n2Groups[gName] =
                 this.dom.n2InnerGroup.append('g')
                     .attr('id', 'n2' + gName);
@@ -236,10 +256,12 @@ class N2Diagram {
         this.scales.model.x
             .domain([this.zoomedElement.dims.x, 1])
             .range([this.zoomedElement.dims.x ? this.layout.size.parentNodeWidth : 0,
-            this.layout.size.partitionTree.width]);
+            this.layout.size.partitionTree.width
+            ]);
         this.scales.model.y
             .domain([this.zoomedElement.dims.y, this.zoomedElement.dims.y +
-                this.zoomedElement.dims.height])
+                this.zoomedElement.dims.height
+            ])
             .range([0, this.layout.size.partitionTree.height]);
 
         this.transitCoords.solver.x = (this.zoomedElement.solverDims.x ?
@@ -251,10 +273,12 @@ class N2Diagram {
         this.scales.solver.x
             .domain([this.zoomedElement.solverDims.x, 1])
             .range([this.zoomedElement.solverDims.x ? this.layout.size.parentNodeWidth :
-                0, this.layout.size.solverTree.width]);
+                0, this.layout.size.solverTree.width
+            ]);
         this.scales.solver.y
             .domain([this.zoomedElement.solverDims.y,
-            this.zoomedElement.solverDims.y + this.zoomedElement.solverDims.height])
+            this.zoomedElement.solverDims.y + this.zoomedElement.solverDims.height
+            ])
             .range([0, this.layout.size.solverTree.height]);
 
         if (this.scales.firstRun) { // first run, duplicate what we just calculated
@@ -309,17 +333,6 @@ class N2Diagram {
                 .attr("width", innerDims.height)
                 .attr("height", offgridHeight);
 
-                /*
-            this.dom.n2Groups.offgrid.top
-                .append("text")
-                .attr("x", 0).attr("y", 0)
-                // .attr("transform", "translate(0 0)")
-                //.attr("width", innerDims.height)
-                //.attr("height", offgridHeight)
-                //.style("fill", "black")
-                .text("HOWDY.HOWDY.HOWDY.HOWDY");
-                */
-
             this.dom.n2Groups.offgrid.bottom
                 .attr("transform", "translate(0 " + innerDims.height + offgridHeight + ")")
                 .attr("width", outerDims.height)
@@ -331,10 +344,12 @@ class N2Diagram {
         let self = this; // For callbacks that change "this". Alternative to using .bind().
 
         let selection = this.dom.pTreeGroup.selectAll(".partition_group")
-            .data(this.layout.zoomedNodes, function (node) { return node.id; });
+            .data(this.layout.zoomedNodes, function (node) {
+                return node.id;
+            });
 
         // Create a new SVG group for each node in zoomedNodes
-        let nodeEnter = selection.enter().append("svg:g")
+        let nodeEnter = selection.enter().append("g")
             .attr("class", function (d) {
                 return "partition_group " + self.style.getNodeClass(d);
             })
@@ -343,44 +358,34 @@ class N2Diagram {
                     self.prevScales.model.x(d.prevDims.x) + " " +
                     self.prevScales.model.y(d.prevDims.y) + ")";
             })
-            .on("click", function (d) { self.ui.leftClick(d); })
-            .on("contextmenu", function (d) { self.ui.rightClick(d, this); })
+            .on("click", function (d) {
+                self.ui.leftClick(d);
+            })
+            .on("contextmenu", function (d) {
+                self.ui.rightClick(d, this);
+            })
             .on("mouseover", function (d) {
-                if (self.model.abs2prom != undefined) {
-                    if (d.isParam()) {
-                        return self.dom.toolTip.text(
-                            self.model.abs2prom.input[d.absPathName])
-                            .style("visibility", "visible");
-                    }
-                    if (d.isUnknown()) {
-                        return self.dom.toolTip.text(
-                            self.model.abs2prom.output[d.absPathName])
-                            .style("visibility", "visible");
-                    }
-                }
+                self.ui.nodeInfoBox.update(d3.event, d, d3.select(this).select('rect').style('fill'));
             })
             .on("mouseleave", function (d) {
-                if (self.model.abs2prom != undefined) {
-                    return self.dom.toolTip.style("visibility", "hidden");
-                }
+                self.ui.nodeInfoBox.clear();
             })
             .on("mousemove", function () {
-                if (self.model.abs2prom != undefined) {
-                    return self.dom.toolTip.style("top", (d3.event.pageY - 30) + "px")
-                        .style("left", (d3.event.pageX + 5) + "px");
-                }
+                self.ui.nodeInfoBox.move(d3.event);
             });
 
-        nodeEnter.append("svg:rect")
+        nodeEnter.append("rect")
             .attr("width", function (d) {
                 return d.prevDims.width * self.prevTransitCoords.model.x;
             })
             .attr("height", function (d) {
                 return d.prevDims.height * self.prevTransitCoords.model.y;
             })
-            .attr("id", function(d) { return d.absPathName.replace(/\./g,'_'); });
+            .attr("id", function (d) {
+                return d.absPathName.replace(/\./g, '_');
+            });
 
-        nodeEnter.append("svg:text")
+        nodeEnter.append("text")
             .attr("dy", ".35em")
             .attr("transform", function (d) {
                 let anchorX = d.prevDims.width * self.prevTransitCoords.model.x -
@@ -394,7 +399,10 @@ class N2Diagram {
             })
             .text(self.layout.getText.bind(self.layout));
 
-        return { 'selection': selection, 'nodeEnter': nodeEnter };
+        return {
+            'selection': selection,
+            'nodeEnter': nodeEnter
+        };
     }
 
     _setupPartitionTransition(d3Refs) {
@@ -420,7 +428,9 @@ class N2Diagram {
             })
             .attr("height", function (d) {
                 return d.dims.height * self.transitCoords.model.y;
-            });
+            })
+            .attr('rx', 12)
+            .attr('ry', 12);
 
         nodeUpdate.select("text")
             .attr("transform", function (d) {
@@ -475,8 +485,10 @@ class N2Diagram {
 
         let nodeEnter = selection.enter().append("svg:g")
             .attr("class", function (d) {
-                let solver_class = self.style.getSolverClass(self.showLinearSolverNames,
-                    { 'linear': d.linear_solver, 'nonLinear': d.nonlinear_solver });
+                let solver_class = self.style.getSolverClass(self.showLinearSolverNames, {
+                    'linear': d.linear_solver,
+                    'nonLinear': d.nonlinear_solver
+                });
                 return solver_class + " solver_group " + self.style.getNodeClass(d);
             })
             .attr("transform", function (d) {
@@ -486,9 +498,15 @@ class N2Diagram {
                 return "translate(" + self.prevScales.solver.x(x) + "," +
                     self.prevScales.solver.y(d.prevSolverDims.y) + ")";
             })
-            .on("click", function (d) { self.ui.leftClick(d); })
-            .on("contextmenu", function (d) { self.ui.rightClick(d, this); })
+            .on("click", function (d) {
+                self.ui.leftClick(d);
+            })
+            .on("contextmenu", function (d) {
+                self.ui.rightClick(d, this);
+            })
             .on("mouseover", function (d) {
+                self.ui.nodeInfoBox.update(d3.event, d, d3.select(this).select('rect').style('fill'))
+
                 if (self.model.abs2prom != undefined) {
                     if (d.isParam()) {
                         return self.dom.toolTip.text(self.model.abs2prom.input[d.absPathName])
@@ -501,13 +519,15 @@ class N2Diagram {
                 }
             })
             .on("mouseleave", function (d) {
+                self.ui.nodeInfoBox.clear();
+
                 if (self.model.abs2prom != undefined) {
-                    return self.dom.toolTip.style("visibility", "hidden");
+                    self.dom.toolTip.style("visibility", "hidden");
                 }
             })
             .on("mousemove", function () {
                 if (self.model.abs2prom != undefined) {
-                    return self.dom.toolTip.style("top", (d3.event.pageY - 30) + "px")
+                    self.dom.toolTip.style("top", (d3.event.pageY - 30) + "px")
                         .style("left", (d3.event.pageX + 5) + "px");
                 }
             });
@@ -519,7 +539,9 @@ class N2Diagram {
             .attr("height", function (d) {
                 return d.prevSolverDims.height * self.prevTransitCoords.solver.y;
             })
-            .attr("id", function(d) { return d.absPathName.replace(/\./g, '_'); });
+            .attr("id", function (d) {
+                return d.absPathName.replace(/\./g, '_');
+            });
 
         nodeEnter.append("svg:text")
             .attr("dy", ".35em")
@@ -535,7 +557,10 @@ class N2Diagram {
             })
             .text(self.layout.getSolverText.bind(self.layout));
 
-        return ({ 'selection': selection, 'nodeEnter': nodeEnter });
+        return ({
+            'selection': selection,
+            'nodeEnter': nodeEnter
+        });
     }
 
     _setupSolverTransition(d3Refs) {
@@ -548,8 +573,10 @@ class N2Diagram {
         let nodeUpdate = d3Refs.nodeEnter.merge(d3Refs.selection)
             .transition(sharedTransition)
             .attr("class", function (d) {
-                let solver_class = self.style.getSolverClass(self.showLinearSolverNames,
-                    { 'linear': d.linear_solver, 'nonLinear': d.nonlinear_solver });
+                let solver_class = self.style.getSolverClass(self.showLinearSolverNames, {
+                    'linear': d.linear_solver,
+                    'nonLinear': d.nonlinear_solver
+                });
                 return solver_class + " solver_group " + self.style.getNodeClass(d);
             })
             .attr("transform", function (d) {
@@ -560,13 +587,17 @@ class N2Diagram {
                     self.scales.solver.y(d.solverDims.y) + ")";
             });
 
+
+
         nodeUpdate.select("rect")
             .attr("width", function (d) {
                 return d.solverDims.width * self.transitCoords.solver.x;
             })
             .attr("height", function (d) {
                 return d.solverDims.height * self.transitCoords.solver.y;
-            });
+            })
+            .attr('rx', 12)
+            .attr('ry', 12);
 
         nodeUpdate.select("text")
             .attr("transform", function (d) {
@@ -616,6 +647,25 @@ class N2Diagram {
         this.dom.n2OuterGroup.selectAll("[class^=n2_hover_elements]").remove();
     }
 
+    showArrows() {
+        for (let i = 0; i < this.arrowCache.length; i++) {
+            const arrow = this.arrowCache[i];
+            this.mouseOverOnDiagonal(arrow.cell);
+            arrow.element.attr('class', arrow.className);
+        };
+
+    }
+
+    showAllArrows() {
+        for (let i = 0; i < this.matrix.visibleCells.length; i++) {
+            const cell = this.matrix.visibleCells[i];
+            if (cell.renderer.color !== "black") {
+                this.mouseOverOnDiagonal(cell);
+                this.mouseClickAll(cell);
+            }
+        };
+    }
+
     /**
      * Refresh the diagram when something has visually changed.
      * @param {Boolean} [computeNewTreeLayout = true] Whether to rebuild the layout and
@@ -677,20 +727,11 @@ class N2Diagram {
      * @param {number} height The new height in pixels.
      */
     verticalResize(height) {
-        for (let i = 600; i <= 1000; i += 50) {
-            let newText = (i == height) ? ("<b>" + i + "px</b>") : (i + "px");
-            this.dom.parentDiv.querySelector("#idVerticalResize" + i + "px").innerHTML = newText;
-        }
-        for (let i = 2000; i <= 4000; i += 1000) {
-            let newText = (i == height) ? ("<b>" + i + "px</b>") : (i + "px");
-            this.dom.parentDiv.querySelector("#idVerticalResize" + i + "px").innerHTML = newText;
-        }
 
         this.clearArrows();
         this.updateSizes(height, this.dims.size.font);
 
         N2TransitionDefaults.duration = N2TransitionDefaults.durationFast;
-        this.style.updateSvgStyle(this.dims.size.font);
         this.update();
     }
 
@@ -699,13 +740,6 @@ class N2Diagram {
      * @param {number} fontSize The new font size in pixels.
      */
     fontSizeSelectChange(fontSize) {
-        for (let i = 8; i <= 14; ++i) {
-            let newText = (i == fontSize) ? ("<b>" + i + "px</b>") : (i + "px");
-            this.dom.parentDiv.querySelector("#idFontSize" + i + "px").innerHTML = newText;
-        }
-
-        this.updateSizes(this.dims.size.n2matrix.height, fontSize);
-
         N2TransitionDefaults.duration = N2TransitionDefaults.durationFast;
         this.style.updateSvgStyle(fontSize);
         this.update();
@@ -717,8 +751,20 @@ class N2Diagram {
      * @param {N2MatrixCell} cell The cell the event occured on.
      */
     mouseOverOnDiagonal(cell) {
-        if (this.matrix.cellExists(cell))
+        if (this.matrix.cellExists(cell)) {
             this.matrix.mouseOverOnDiagonal(cell);
+            this.ui.nodeInfoBox.update(d3.event, cell.obj, cell.color());
+        }
+    }
+
+    /**
+     * Move the node info panel around if it's visible
+     * @param {N2MatrixCell} cell The cell the event occured on.
+     */
+    mouseMoveOnDiagonal(cell) {
+        if (this.matrix.cellExists(cell)) {
+            this.ui.nodeInfoBox.move(d3.event);
+        }
     }
 
     /**
@@ -726,8 +772,9 @@ class N2Diagram {
      * rather than setting one up that points directly to a specific matrix.
      */
     mouseOverOffDiagonal(cell) {
-        if (this.matrix.cellExists(cell))
+        if (this.matrix.cellExists(cell)) {
             this.matrix.mouseOverOffDiagonal(cell);
+        }
     }
 
     /** When the mouse leaves a cell, remove all temporary arrows. */
@@ -735,7 +782,9 @@ class N2Diagram {
         this.dom.n2OuterGroup.selectAll(".n2_hover_elements").remove();
         d3.selectAll("div.offgrid")
             .style("visibility", "hidden")
-            .node().innerHTML = '';
+            .html('');
+
+        this.ui.nodeInfoBox.clear();
     }
 
     /**
@@ -744,6 +793,33 @@ class N2Diagram {
      * @param {N2MatrixCell} cell The cell the event occured on.
      */
     mouseClick(cell) {
+        let newClassName = "n2_hover_elements_" + cell.row + "_" + cell.col;
+        let selection = this.dom.n2OuterGroup.selectAll("." + newClassName);
+        if (selection.size() > 0) {
+            selection.remove();
+            const arrow = this.arrowCache.find(o => o.cell.row === cell.row && o.cell.col === cell.col);
+            const arrowIndex = this.arrowCache.indexOf(arrow);
+            this.arrowCache.splice(arrowIndex, 1);
+        }
+        else {
+            const arrow = {
+                'cell': cell,
+                'element': this.dom.n2OuterGroup
+                    .selectAll("path.n2_hover_elements, circle.n2_hover_elements"),
+                'className': newClassName
+            }
+            this.arrowCache.push(arrow);
+            this.dom.n2OuterGroup
+                .selectAll("path.n2_hover_elements, circle.n2_hover_elements")
+                .attr("class", newClassName);
+        }
+    }
+
+    clearActiveNode() {
+        this.dom.nodeInfo.html('');
+    }
+
+    mouseClickAll(cell) {
         let newClassName = "n2_hover_elements_" + cell.row + "_" + cell.col;
         let selection = this.dom.n2OuterGroup.selectAll("." + newClassName);
         if (selection.size() > 0) {
@@ -759,13 +835,14 @@ class N2Diagram {
     /**
      * Place member mouse callbacks in an object for easy reference.
      * @returns {Object} Object containing each of the functions.
-    */
+     */
     getMouseFuncs() {
         let self = this;
 
         let mf = {
             'overOffDiag': self.mouseOverOffDiagonal.bind(self),
             'overOnDiag': self.mouseOverOnDiagonal.bind(self),
+            'moveOnDiag': self.mouseMoveOnDiagonal.bind(self),
             'out': self.mouseOut.bind(self),
             'click': self.mouseClick.bind(self)
         }
