@@ -45,7 +45,7 @@ class N2Layout {
         startTimer('N2Layout._updateSolverTextWidths');
         this._updateSolverTextWidths();
         stopTimer('N2Layout._updateSolverTextWidths');
-        delete (this.textRenderer);
+        delete(this.textRenderer);
 
         startTimer('N2Layout._computeLeaves');
         this._computeLeaves();
@@ -154,7 +154,7 @@ class N2Layout {
     }
 
     /** Determine the text associated with the node. Normally its name,
-     * but can be changed if promoted or originally contained a colon.
+     * but can be changed if promoted.
      * @param {N2TreeNode} node The item to operate on.
      * @return {string} The selected text.
      */
@@ -170,16 +170,6 @@ class N2Layout {
             retVal = this.zoomedElement.promotions[node.absPathName];
         }
 
-        if (node.splitByColon) {
-            if (retVal.endsWith(colonVarNameAppend)) {
-                retVal = retVal.slice(0,-1);
-            }
-        }
-
-        if (node.splitByColon && node.hasChildren()) {
-            retVal += ":";
-        }
-
         return retVal;
     }
 
@@ -193,9 +183,10 @@ class N2Layout {
 
         let solver_name = this.showLinearSolverNames ? node.linear_solver : node.nonlinear_solver;
 
-        if (!this.showLinearSolverNames && node.hasOwnProperty("solve_subsystems") && node.solve_subsystems){
+        if (!this.showLinearSolverNames && node.hasOwnProperty("solve_subsystems") && node.solve_subsystems) {
             return solver_name + " (sub_solve)";
-        } else {
+        }
+        else {
             return solver_name;
         }
     }
@@ -293,8 +284,13 @@ class N2Layout {
     _computeColumnWidths(node = this.zoomedElement) {
         this.greatestDepth = 0;
         this.leafWidthsPx = new Array(this.model.maxDepth + 1).fill(0.0);
-        this.cols = Array.from({ length: this.model.maxDepth + 1 }, () =>
-            ({ 'width': 0.0, 'location': 0.0 }));
+        this.cols = Array.from({
+                length: this.model.maxDepth + 1
+            }, () =>
+            ({
+                'width': 0.0,
+                'location': 0.0
+            }));
 
         this._setColumnWidthsFromWidestText(node, 'children', this.cols,
             this.leafWidthsPx, 'nameWidthPx');
@@ -317,8 +313,13 @@ class N2Layout {
     _computeSolverColumnWidths(node = this.zoomedElement) {
         this.greatestDepth = 0;
         this.leafSolverWidthsPx = new Array(this.model.maxDepth + 1).fill(0.0);
-        this.solverCols = Array.from({ length: this.model.maxDepth + 1 }, () =>
-            ({ 'width': 0.0, 'location': 0.0 }));
+        this.solverCols = Array.from({
+                length: this.model.maxDepth + 1
+            }, () =>
+            ({
+                'width': 0.0,
+                'location': 0.0
+            }));
 
         this._setColumnWidthsFromWidestText(node, 'subsystem_children', this.solverCols,
             this.leafSolverWidthsPx, 'nameSolverWidthPx');
@@ -477,7 +478,10 @@ class N2Layout {
         let height = (this.size.n2matrix.height +
             this.size.n2matrix.margin * 2);
 
-        return ({ 'width': width, 'height': height });
+        return ({
+            'width': width,
+            'height': height
+        });
     }
 
     /**
@@ -494,7 +498,11 @@ class N2Layout {
         let height = this.size.partitionTree.height;
         let margin = this.size.n2matrix.margin;
 
-        return ({ 'width': width, 'height': height, 'margin': margin });
+        return ({
+            'width': width,
+            'height': height,
+            'margin': margin
+        });
     }
 
     /**
@@ -526,7 +534,7 @@ class N2Layout {
             .attr("height", innerDims.height)
             .attr("width", this.size.partitionTree.width)
             .attr("transform", "translate(0 " + innerDims.margin + ")");
-           
+
         // Move n2 outer group to right of partition tree, spaced by the margin.
         dom.n2OuterGroup.transition(sharedTransition)
             .attr("height", outerDims.height)
@@ -547,9 +555,9 @@ class N2Layout {
         dom.pSolverTreeGroup.transition(sharedTransition)
             .attr("height", innerDims.height)
             .attr("transform", "translate(" + (this.size.partitionTree.width +
-                innerDims.margin +
-                innerDims.height +
-                innerDims.margin) + " " +
+                    innerDims.margin +
+                    innerDims.height +
+                    innerDims.margin) + " " +
                 innerDims.margin + ")");
     }
 }
\ No newline at end of file
