@@ -25,7 +25,10 @@ class N2Matrix {
      */
     constructor(model, layout, n2Groups, lastClickWasLeft,
         findRootOfChangeFunction,
-        prevNodeSize = { 'width': 0, 'height': 0 }) {
+        prevNodeSize = {
+            'width': 0,
+            'height': 0
+        }) {
 
         this.layout = layout;
         this.diagNodes = layout.visibleNodes;
@@ -55,8 +58,13 @@ class N2Matrix {
         stopTimer('N2Matrix._setupComponentBoxesAndGridLines');
     }
 
-    get cellDims() { return N2CellRenderer.dims; }
-    get prevCellDims() { return N2CellRenderer.prevDims; }
+    get cellDims() {
+        return N2CellRenderer.dims;
+    }
+
+    get prevCellDims() {
+        return N2CellRenderer.prevDims;
+    }
 
     /**
      * Determine if a node exists at the specified location.
@@ -75,7 +83,7 @@ class N2Matrix {
      * @param {N2MatrixCell} cell The cell to test.
      * @returns {Boolean} True if this.diagNodes has an object in the
      *   same row and column, and it matches the provided cell.
-    */
+     */
     cellExists(cell) {
         return (this.exists(cell.row, cell.col) &&
             this.cell(cell.row, cell.col) === cell);
@@ -164,6 +172,7 @@ class N2Matrix {
                 if (!found) {
                     for (let tgt of ai.src.targetParentSet) {
                         if (tgt.absPathName == node.absPathName) {
+                            debugInfo("Adding offscreen connection from _findUnseenCycleSources().")
                             cell.addOffScreenConn(ai.src, node)
                         }
                     }
@@ -197,19 +206,25 @@ class N2Matrix {
 
             for (let tgt of diagNode.targetParentSet) {
                 let tgtIdx = indexFor(this.diagNodes, tgt);
+
                 if (tgtIdx != -1) {
                     let newCell = new N2MatrixCell(srcIdx, tgtIdx, diagNode, tgt, model);
                     this._addCell(srcIdx, tgtIdx, newCell);
                 }
-                else if (tgt.isConnectable()) {
+                // Make sure tgt isn't descendant of zoomedElement, otherwise it's
+                // visiable at least as a collapsed node
+                else if (tgt.isConnectable() && !this.layout.zoomedElement.hasNode(tgt)) {
                     newDiagCell.addOffScreenConn(diagNode, tgt);
                 }
             }
 
             // Check for missing source part of connections
             for (let src of diagNode.sourceParentSet) {
+
                 if (indexFor(this.diagNodes, src) == -1) {
-                    if (src.isConnectable()) {
+                    // Make sure src isn't descendant of zoomedElement, otherwise it's
+                    // visiable at least as a collapsed node
+                    if (src.isConnectable() && !this.layout.zoomedElement.hasNode(src)) {
                         newDiagCell.addOffScreenConn(src, diagNode);
                     }
                 }
@@ -229,13 +244,17 @@ class N2Matrix {
                 }
             }
         }
+
     }
 
     /**
      * Determine the size of the boxes that will border the parameters of each component.
      */
     _setupComponentBoxesAndGridLines() {
-        let currentBox = { "startI": 0, "stopI": 0 };
+        let currentBox = {
+            "startI": 0,
+            "stopI": 0
+        };
 
         this.boxInfo = [currentBox];
 
@@ -251,7 +270,10 @@ class N2Matrix {
                 ++currentBox.stopI;
             }
             else {
-                currentBox = { "startI": ri, "stopI": ri };
+                currentBox = {
+                    "startI": ri,
+                    "stopI": ri
+                };
             }
             this.boxInfo.push(currentBox);
         }
@@ -276,7 +298,10 @@ class N2Matrix {
         if (!this.tooMuchDetail()) {
             for (let i = 0; i < this.diagNodes.length; ++i) {
                 let obj = this.diagNodes[i];
-                let gl = { "i": i, "obj": obj };
+                let gl = {
+                    "i": i,
+                    "obj": obj
+                };
                 this.gridLines.push(gl);
             }
         }
@@ -345,6 +370,7 @@ class N2Matrix {
                 // "this" refers to the element here, so leave it alone:
                 d.renderer.renderPrevious(this)
                     .on('mouseover', d.mouseover())
+                    .on('mousemove', d.mousemove())
                     .on('mouseleave', n2MouseFuncs.out)
                     .on('click', n2MouseFuncs.click);
             });
@@ -358,7 +384,9 @@ class N2Matrix {
                         self.cellDims.bottomRight.y) + ')';
             })
             // "this" refers to the element here, so leave it alone:
-            .each(function (d) { d.renderer.updateCurrent(this) });
+            .each(function (d) {
+                d.renderer.updateCurrent(this)
+            });
 
         selection.exit()
             .transition(sharedTransition)
@@ -381,7 +409,9 @@ class N2Matrix {
                 throw ('Exit transform not found');
             })
             // "this" refers to the element here, so leave it alone:
-            .each(function (d) { d.renderer.updateCurrent(this) })
+            .each(function (d) {
+                d.renderer.updateCurrent(this)
+            })
             .remove();
     }
 
@@ -497,7 +527,7 @@ class N2Matrix {
                         (self.prevCellDims.size.height * index0) + ")";
                 }
                 throw ("enter transform not found");
-            });
+            })
 
         gEnter.append("rect")
             .attr("width", function (d) {
@@ -591,7 +621,10 @@ class N2Matrix {
             for (let dir in cell.offScreen[side]) {
                 for (let offscreenNode of cell.offScreen[side][dir]) {
                     new (N2OffGridArrow.arrowDir[side][dir])({
-                        'cell': { 'col': cell.row, 'row': cell.row },
+                        'cell': {
+                            'col': cell.row,
+                            'row': cell.row
+                        },
                         'width': lineWidth,
                         'matrixSize': this.diagNodes.length,
                         'label': offscreenNode.absPathName
@@ -629,8 +662,14 @@ class N2Matrix {
                 if (col != cell.row) {
 
                     new N2BentArrow({
-                        'end': { 'col': col, 'row': col },
-                        'start': { 'col': cell.row, 'row': cell.row },
+                        'end': {
+                            'col': col,
+                            'row': col
+                        },
+                        'start': {
+                            'col': cell.row,
+                            'row': cell.row
+                        },
                         'color': N2Style.color.greenArrow,
                         'width': lineWidth
                     }, this.n2Groups, this.nodeSize);
@@ -648,8 +687,14 @@ class N2Matrix {
                 if (col != cell.row) {
 
                     new N2BentArrow({
-                        'start': { 'col': col, 'row': col },
-                        'end': { 'col': cell.row, 'row': cell.row },
+                        'start': {
+                            'col': col,
+                            'row': col
+                        },
+                        'end': {
+                            'col': cell.row,
+                            'row': cell.row
+                        },
                         'color': N2Style.color.redArrow,
                         'width': lineWidth
                     }, this.n2Groups, this.nodeSize);
@@ -675,7 +720,10 @@ class N2Matrix {
         for (let startsI = boxStart.startI; startsI <= boxStart.stopI; ++startsI) {
             for (let endsI = boxEnd.startI; endsI <= boxEnd.stopI; ++endsI) {
                 if (this.exists(startsI, endsI)) {
-                    arrows.push({ 'start': startsI, 'end': endsI });
+                    arrows.push({
+                        'start': startsI,
+                        'end': endsI
+                    });
                 }
                 /*
                 else {
@@ -686,8 +734,14 @@ class N2Matrix {
 
         for (let arrow of arrows) {
             new N2BentArrow({
-                'start': { 'col': arrow.start, 'row': arrow.start },
-                'end': { 'col': arrow.end, 'row': arrow.end },
+                'start': {
+                    'col': arrow.start,
+                    'row': arrow.start
+                },
+                'end': {
+                    'col': arrow.end,
+                    'row': arrow.end
+                },
                 'color': (startIndex < endIndex) ?
                     N2Style.color.greenArrow : N2Style.color.redArrow,
                 'width': lineWidth
@@ -709,8 +763,14 @@ class N2Matrix {
         let tgt = this.diagNodes[cell.col];
 
         new N2BentArrow({
-            'start': { 'col': cell.row, 'row': cell.row },
-            'end': { 'col': cell.col, 'row': cell.col },
+            'start': {
+                'col': cell.row,
+                'row': cell.row
+            },
+            'end': {
+                'col': cell.col,
+                'row': cell.col
+            },
             'color': N2Style.color.redArrow,
             'width': lineWidth
         }, this.n2Groups, this.nodeSize);
@@ -722,7 +782,8 @@ class N2Matrix {
                 for (let ai of twca.cycleArrows) {
                     if (src.hasNode(ai.src)) {
                         for (let arrow of ai.arrows) {
-                            let firstBeginIndex = -1, firstEndIndex = -1;
+                            let firstBeginIndex = -1,
+                                firstEndIndex = -1;
 
                             // find first begin index
                             for (let mi in this.diagNodes) {
@@ -771,4 +832,4 @@ class N2Matrix {
             this.nodeSize.height * cell.col, leftTextWidthC, this.nodeSize.height,
             N2Style.color.greenArrow);
     }
-}
+}
\ No newline at end of file
