@@ -14,9 +14,18 @@ class N2CellRenderer {
     static updateDims(baseWidth, baseHeight) {
         if (!N2CellRenderer.dims) {
             N2CellRenderer.prevDims = {
-                "size": { "width": 0, "height": 0 },
-                "bottomRight": { "x": 0, "y": 0 },
-                "topLeft": { "x": 0, "y": 0 }
+                "size": {
+                    "width": 0,
+                    "height": 0
+                },
+                "bottomRight": {
+                    "x": 0,
+                    "y": 0
+                },
+                "topLeft": {
+                    "x": 0,
+                    "y": 0
+                }
             }
         }
         else {
@@ -361,7 +370,7 @@ class N2GroupGroupCell extends N2GroupBase {
  * @property {N2TreeNode} tgtObj The model tree node that this outputs to.
  * @property {string} id The srcObj id appended with the tgtObj id.
  * @property {SymbolType} symbolType Info about the type of symbol represented by the node.
-*/
+ */
 class N2MatrixCell {
     /**
      * Initialize the cell.
@@ -371,7 +380,7 @@ class N2MatrixCell {
      * @param {N2TreeNode} tgtObj The model tree node that this outputs to.
      * @param {ModelData} model Reference to the model to get some info from it.
      * @param {N2CellRenderer} renderer The object that draws the cell.
-    */
+     */
     constructor(row, col, srcObj, tgtObj, model) {
         this.row = row;
         this.col = col;
@@ -383,8 +392,14 @@ class N2MatrixCell {
         this.renderer = this._newRenderer();
 
         this.offScreen = {
-            "top": { "incoming": new Set(), "outgoing": new Set() },
-            "bottom": { "incoming": new Set(), "outgoing": new Set() },
+            "top": {
+                "incoming": new Set(),
+                "outgoing": new Set()
+            },
+            "bottom": {
+                "incoming": new Set(),
+                "outgoing": new Set()
+            },
             "total": 0
         }
     }
@@ -392,7 +407,7 @@ class N2MatrixCell {
     /**
      * Determine if this node is on the main diagonal of the matrix.
      * @return {Boolean} True if row equals column.
-    */
+     */
     onDiagonal() {
         return (this.row == this.col);
     }
@@ -406,6 +421,14 @@ class N2MatrixCell {
             n2MouseFuncs.overOffDiag);
     }
 
+     /**
+     * Select the mousemove callback depending on whether we"re on the diagonal.
+     * TODO: Remove these globals
+     */
+    mousemove() {
+        return (this.onDiagonal() ? n2MouseFuncs.moveOnDiag : null);
+    }
+
     /**
      * Choose a color based on our location and state of the associated N2TreeNode.
      */
@@ -471,18 +494,30 @@ class N2MatrixCell {
      */
     _newRenderer() {
         switch (this.symbolType.name) {
-            case "scalar": return new N2ScalarCell(this.color(), this.id);
-            case "vector": return new N2VectorCell(this.color(), this.id);
-            case "group": return new N2GroupCell(this.color(), this.id);
-            case "scalarScalar": return new N2ScalarScalarCell(this.color(), this.id);
-            case "scalarVector": return new N2ScalarVectorCell(this.color(), this.id);
-            case "vectorScalar": return new N2VectorScalarCell(this.color(), this.id);
-            case "vectorVector": return new N2VectorVectorCell(this.color(), this.id);
-            case "scalarGroup": return new N2ScalarGroupCell(this.color(), this.id);
-            case "groupScalar": return new N2GroupScalarCell(this.color(), this.id);
-            case "vectorGroup": return new N2VectorGroupCell(this.color(), this.id);
-            case "groupVector": return new N2GroupVectorCell(this.color(), this.id);
-            case "groupGroup": return new N2GroupGroupCell(this.color(), this.id);
+            case "scalar":
+                return new N2ScalarCell(this.color(), this.id);
+            case "vector":
+                return new N2VectorCell(this.color(), this.id);
+            case "group":
+                return new N2GroupCell(this.color(), this.id);
+            case "scalarScalar":
+                return new N2ScalarScalarCell(this.color(), this.id);
+            case "scalarVector":
+                return new N2ScalarVectorCell(this.color(), this.id);
+            case "vectorScalar":
+                return new N2VectorScalarCell(this.color(), this.id);
+            case "vectorVector":
+                return new N2VectorVectorCell(this.color(), this.id);
+            case "scalarGroup":
+                return new N2ScalarGroupCell(this.color(), this.id);
+            case "groupScalar":
+                return new N2GroupScalarCell(this.color(), this.id);
+            case "vectorGroup":
+                return new N2VectorGroupCell(this.color(), this.id);
+            case "groupVector":
+                return new N2GroupVectorCell(this.color(), this.id);
+            case "groupGroup":
+                return new N2GroupGroupCell(this.color(), this.id);
         }
     }
 }
\ No newline at end of file
