@@ -3,7 +3,6 @@
  * @typedef N2Style
  */
 class N2Style {
-
     constructor(svgStyle, fontSize) {
         this.svgStyle = svgStyle;
 
@@ -22,13 +21,17 @@ class N2Style {
                     this.solvers[sdata[i]] = {
                         'name': sdata[i],
                         'type': solverTypes[i],
-                        'class': 'solver_' + sdata[i].toLowerCase().replace(/[: ]/g, '_').replace(/_+/g, '_'),
+                        'class': 'solver_' +
+                            sdata[i]
+                                .toLowerCase()
+                                .replace(/[: ]/g, '_')
+                                .replace(/_+/g, '_'),
                         'style': {
                             'fill': sdata[2],
                             'cursor': 'pointer',
-                            'fill-opacity': '.8'
-                        }
-                    }
+                            'fill-opacity': '.8',
+                        },
+                    };
                 }
             }
         }
@@ -37,57 +40,57 @@ class N2Style {
     }
 
     /**
-     * Replace the entire content of the SVG style section with new styles.
-     * Doing a wholesale replace is easier than finding each style element,
-     * deleting, and inserting a new one.
-     * @param {number} fontSize In pixel units.
-     */
+       * Replace the entire content of the SVG style section with new styles.
+       * Doing a wholesale replace is easier than finding each style element,
+       * deleting, and inserting a new one.
+       * @param {number} fontSize In pixel units.
+       */
     updateSvgStyle(fontSize) {
         // Define as JSON first
         let newCssJson = {
             'rect': {
-                'stroke': N2Style.color.treeStroke
+                'stroke': N2Style.color.treeStroke,
             },
             'g.unknown > rect': {
                 'fill': N2Style.color.unknownExplicit,
-                'fill-opacity': '.8'
+                'fill-opacity': '.8',
             },
             'g.unknown_implicit > rect': {
                 'fill': N2Style.color.unknownImplicit,
-                'fill-opacity': '.8'
+                'fill-opacity': '.8',
             },
             'g.param > rect': {
                 'fill': N2Style.color.param,
-                'fill-opacity': '.8'
+                'fill-opacity': '.8',
             },
             'g.unconnected_param > rect': {
                 'fill': N2Style.color.unconnectedParam,
-                'fill-opacity': '.8'
+                'fill-opacity': '.8',
             },
             'g.subsystem > rect': {
                 'cursor': 'pointer',
                 'fill-opacity': '.8',
-                'fill': N2Style.color.group
+                'fill': N2Style.color.group,
             },
             'g.component > rect': {
                 'cursor': 'pointer',
                 'fill-opacity': '.8',
-                'fill': N2Style.color.component
+                'fill': N2Style.color.component,
             },
             'g.param_group > rect': {
                 'cursor': 'pointer',
                 'fill-opacity': '.8',
-                'fill': N2Style.color.paramGroup
+                'fill': N2Style.color.paramGroup,
             },
             'g.unknown_group > rect': {
                 'cursor': 'pointer',
                 'fill-opacity': '.8',
-                'fill': N2Style.color.unknownGroup
+                'fill': N2Style.color.unknownGroup,
             },
             'g.minimized > rect': {
                 'cursor': 'pointer',
                 'fill-opacity': '.8',
-                'fill': N2Style.color.collapsed
+                'fill': N2Style.color.collapsed,
             },
             'text': {
                 //'dominant-baseline: middle',
@@ -127,11 +130,12 @@ class N2Style {
             },
             '.horiz_line, .vert_line': {
                 'stroke': N2Style.color.gridline,
-            }
-        }
+            },
+        };
 
         for (let solverName in this.solvers) {
             let solver = this.solvers[solverName];
+
             newCssJson['g.' + solver.class + ' > rect'] = solver.style;
         }
 
@@ -141,33 +145,39 @@ class N2Style {
         for (let selector in newCssJson) {
             newCssText += selector + ' {\n';
             for (let attrib in newCssJson[selector]) {
-                newCssText += '    ' + attrib + ': ' + newCssJson[selector][attrib] + ';\n';
+                newCssText +=
+                    '    ' + attrib + ': ' + newCssJson[selector][attrib] + ';\n';
             }
             newCssText += '}\n\n';
+            if (selector === 'g.subsystem > rect') {
+            }
         }
 
         this.svgStyle.innerHTML = newCssText;
     }
 
     /**
-     * Determine the name of the CSS class based on the name of the solver.
-     * @param {boolean} showLinearSolverNames Whether to use the linear or non-linear solver name.
-     * @param {Object} solverNames
-     * @param {string} solverNames.linear The linear solver name.
-     * @param {string} solverNames.nonLinear The non-linear solver name.
-     * @return {string} The CSS class of the solver, or for "other" if not found.
-     */
+       * Determine the name of the CSS class based on the name of the solver.
+       * @param {boolean} showLinearSolverNames Whether to use the linear or non-linear solver name.
+       * @param {Object} solverNames
+       * @param {string} solverNames.linear The linear solver name.
+       * @param {string} solverNames.nonLinear The non-linear solver name.
+       * @return {string} The CSS class of the solver, or for "other" if not found.
+       */
     getSolverClass(showLinearSolverNames, solverNames) {
-        let solverName = showLinearSolverNames? solverNames.linear : solverNames.nonLinear;
-        return this.solvers[solverName]? this.solvers[solverName].class :
-            this.solvers.other.class;
+        let solverName = showLinearSolverNames
+            ? solverNames.linear
+            : solverNames.nonLinear;
+        return this.solvers[solverName]
+            ? this.solvers[solverName].class
+            : this.solvers.other.class;
     }
 
     /**
-     * Based on the element's type and conditionally other info, determine
-     * what CSS style is associated.
-     * @return {string} The name of an existing CSS class.
-     */
+       * Based on the element's type and conditionally other info, determine
+       * what CSS style is associated.
+       * @return {string} The name of an existing CSS class.
+       */
     getNodeClass(element) {
         if (element.isMinimized) return 'minimized';
 
@@ -193,28 +203,27 @@ class N2Style {
                 return 'subsystem';
 
             default:
-                throw ('CSS class not found for element ' + element);
+                throw 'CSS class not found for element ' + element;
         }
-
     }
 }
 
 // From Isaias Reyes
 N2Style.color = {
-    'connection': 'black',
-    'unknownImplicit': '#c7d06d',
-    'unknownExplicit': '#9ec4c7',
+    'connection': '#000000',
+    'unknownImplicit': '#C7D06D',
+    'unknownExplicit': '#9FC4C6',
     'componentBox': '#555',
     'background': '#eee',
     'gridline': 'white',
     'treeStroke': '#eee',
     'unknownGroup': '#888',
-    'param': '#32afad',
+    'param': '#30B0AD',
     'paramGroup': 'Orchid',
-    'group': '#3476a2',
-    'component': 'DeepSkyBlue',
-    'collapsed': '#555',
-    'unconnectedParam': '#f42e0c',
+    'group': '#6092B5',
+    'component': '#02BFFF',
+    'collapsed': '#555555',
+    'unconnectedParam': '#F42F0D',
     'highlightHovered': 'blue',
     'redArrow': 'salmon',
     'greenArrow': 'seagreen',
@@ -246,17 +255,80 @@ Object.freeze(N2Style.color); // Make it the equivalent of a constant
 N2Style.solverStyleData = [
     // [ linear, non-Linear, color ]
     ['None', 'None', '#8dd3c7'],
-    ["LN: LNBJ", "NL: NLBJ", '#ffffb3'],
-    ["LN: SCIPY", null, '#bebada'],
-    ["LN: RUNONCE", "NL: RUNONCE", '#fb8072'],
-    ["LN: Direct", null, '#80b1d3'],
-    ["LN: PETScKrylov", null, '#fdb462'],
-    ["LN: LNBGS", "NL: NLBGS", '#b3de69'],
-    ["LN: USER", null, '#fccde5'],
-    [null, "NL: Newton", '#d9d9d9'],
-    [null, "BROYDEN", '#bc80bd'],
-    ["solve_linear", "solve_nonlinear", '#ccebc5'],
-    ["other", "other", '#ffed6f']
+    ['LN: LNBJ', 'NL: NLBJ', '#ffffb3'],
+    ['LN: SCIPY', null, '#bebada'],
+    ['LN: RUNONCE', 'NL: RUNONCE', '#fb8072'],
+    ['LN: Direct', null, '#80b1d3'],
+    ['LN: PETScKrylov', null, '#fdb462'],
+    ['LN: LNBGS', 'NL: NLBGS', '#b3de69'],
+    ['LN: USER', null, '#fccde5'],
+    [null, 'NL: Newton', '#d9d9d9'],
+    [null, 'BROYDEN', '#bc80bd'],
+    ['solve_linear', 'solve_nonlinear', '#ccebc5'],
+    ['other', 'other', '#ffed6f'],
 ];
 
-Object.freeze(N2Style.solverStyleData); // Make it the equivalent of a constant
\ No newline at end of file
+N2Style.solverStyleObject = [
+    {
+        'ln': 'None',
+        'nl': 'None',
+        'color': '#8dd3c7',
+    },
+    {
+        'ln': 'LN: LNBJ',
+        'nl': 'NL: NLBJ',
+        'color': '#ffffb3',
+    },
+    {
+        'ln': 'LN: SCIPY',
+        'nl': null,
+        'color': '#bebada',
+    },
+    {
+        'ln': 'LN: RUNONCE',
+        'nl': 'NL: RUNONCE',
+        'color': '#fb8072',
+    },
+    {
+        'ln': 'LN: Direct',
+        'nl': null,
+        'color': '#80b1d3',
+    },
+    {
+        'ln': 'LN: PETScKrylov',
+        'nl': null,
+        'color': '#fdb462',
+    },
+    {
+        'ln': 'LN: LNBGS',
+        'nl': 'NL: NLBGS',
+        'color': '#b3de69',
+    },
+    {
+        'ln': 'LN: USER',
+        'nl': null,
+        'color': '#fccde5',
+    },
+    {
+        'ln': null,
+        'nl': 'NL: Newton',
+        'color': '#d9d9d9',
+    },
+    {
+        'ln': null,
+        'nl': 'BROYDEN',
+        'color': '#bc80bd',
+    },
+    {
+        'ln': 'solve_linear',
+        'nl': 'solve_nonlinear',
+        'color': '#ccebc5',
+    },
+    {
+        'ln': 'other',
+        'nl': 'other',
+        'color': '#ffed6f',
+    },
+];
+
+Object.freeze(N2Style.solverStyleData); // Make it the equivalent of a constant
